@@ -1,28 +1,30 @@
-reselect = False            # reselect lines after sending from Visual mode
-show_execution_count = True # wait to get numbers for In[43]: feedback?
-monitor_subchannel = True   # update vim-ipython 'shell' on every send?
-run_flags= "-i"             # flags to for IPython's run magic when using <F5>
+reselect = False  # reselect lines after sending from Visual mode
+show_execution_count = True  # wait to get numbers for In[43]: feedback?
+monitor_subchannel = True  # update vim-ipython 'shell' on every send?
+run_flags = "-i"  # flags to for IPython's run magic when using <F5>
 current_line = ''
 
-
 try:
-    from queue import Empty # python3 convention
+    from queue import Empty  # python3 convention
 except ImportError:
     from Queue import Empty
 
 try:
     import vim
 except ImportError:
+
     class NoOp(object):
+
         def __getattribute__(self, key):
             return lambda *args: '0'
+
     vim = NoOp()
     print("uh oh, not running inside vim")
 
 import sys
 
 # get around unicode problems when interfacing with vim
-vim_encoding=vim.eval('&encoding') or 'utf-8'
+vim_encoding = vim.eval('&encoding') or 'utf-8'
 
 try:
     sys.stdout.flush
@@ -30,22 +32,30 @@ except AttributeError:
     # IPython complains if stderr and stdout don't have flush
     # this is fixed in newer version of Vim
     class WithFlush(object):
-        def __init__(self,noflush):
-            self.write=noflush.write
-            self.writelines=noflush.writelines
-        def flush(self):pass
+
+        def __init__(self, noflush):
+            self.write = noflush.write
+            self.writelines = noflush.writelines
+
+        def flush(self):
+            pass
+
     sys.stdout = WithFlush(sys.stdout)
     sys.stderr = WithFlush(sys.stderr)
 
+
 def vim_variable(name, default=None):
     exists = int(vim.eval("exists('%s')" % name))
     return vim.eval(name) if exists else default
 
+
 def vim_regex_escape(x):
-    for old, new in (("[", "\\["), ("]", "\\]"), (":", "\\:"), (".", "\."), ("*", "\\*")):
+    for old, new in (("[", "\\["), ("]", "\\]"), (":", "\\:"), (".", "\."),
+                     ("*", "\\*")):
         x = x.replace(old, new)
     return x
 
+
 # status buffer settings
 status_prompt_in = vim_variable('g:ipy_status_in', 'In [%(line)d]: ')
 status_prompt_out = vim_variable('g:ipy_status_out', 'Out[%(line)d]: ')
@@ -61,7 +71,6 @@ status_prompt_colors = {
 
 status_blank_lines = int(vim_variable('g:ipy_status_blank_lines', '1'))
 
-
 ip = '127.0.0.1'
 # this allows us to load vim_ipython multiple times
 try:
@@ -83,6 +92,7 @@ instance with which you communicate via vim-ipython needs to be running the
 same version of Python.
 """
 
+
 def new_ipy(s=''):
     """Create a new IPython kernel (optionally with extra arguments)
 
@@ -101,6 +111,7 @@ def new_ipy(s=''):
     km.start_kernel()
     return km_from_string(km.connection_file)
 
+
 def km_from_string(s=''):
     """create kernel manager from IPKernelApp string
     such as '--shell=47378 --iopub=39859 --stdin=36778 --hb=52668' for IPython 0.11
@@ -116,11 +127,12 @@ def km_from_string(s=''):
     from traitlets.config.loader import KeyValueConfigLoader
     try:
         # Updated by Bo Peng for module names
-        from jupyter_client.manager import  KernelManager
         from jupyter_client import find_connection_file
+        from jupyter_client.manager import KernelManager
     except ImportError:
         #  IPython < 1.0
-        from IPython.zmq.blockingkernelmanager import BlockingKernelManager as KernelManager
+        from IPython.zmq.blockingkernelmanager import \
+            BlockingKernelManager as KernelManager
         from IPython.zmq.kernelapp import kernel_aliases
         try:
             from IPython.lib.kernel import find_connection_file
@@ -142,17 +154,17 @@ def km_from_string(s=''):
             # whether or not they are allowed to have spaces. I'll have to sync
             # up with the IPython team to address these issues -pi
             if '--profile' in s:
-                k,p = s.split('--profile')
-                k = k.lstrip().rstrip() # kernel part of the string
-                p = p.lstrip().rstrip() # profile part of the string
-                fullpath = find_connection_file(k,p)
+                k, p = s.split('--profile')
+                k = k.lstrip().rstrip()  # kernel part of the string
+                p = p.lstrip().rstrip()  # profile part of the string
+                fullpath = find_connection_file(k, p)
             else:
                 fullpath = find_connection_file(s.lstrip().rstrip())
         except IOError as e:
             echo(":IPython " + s + " failed", "Info")
             echo("^-- failed '" + s + "' not found", "Error")
             return
-        km = KernelManager(connection_file = fullpath)
+        km = KernelManager(connection_file=fullpath)
         km.load_connection_file()
     else:
         if s == '':
@@ -167,8 +179,10 @@ def km_from_string(s=''):
                 stdin_address=(ip, cfg['stdin_port']),
                 hb_address=(ip, cfg['hb_port']))
         except KeyError as e:
-            echo(":IPython " +s + " failed", "Info")
-            echo("^-- failed --"+e.message.replace('_port','')+" not specified", "Error")
+            echo(":IPython " + s + " failed", "Info")
+            echo(
+                "^-- failed --" + e.message.replace('_port', '') +
+                " not specified", "Error")
             return
 
     try:
@@ -193,7 +207,7 @@ def km_from_string(s=''):
             # patch the object_info method which used to only take one argument
             klass = sc.__class__
             klass._oinfo_orig = klass.object_info
-            klass.object_info = lambda s,x,y: s._oinfo_orig(x)
+            klass.object_info = lambda s, x, y: s._oinfo_orig(x)
     except Exception:
         pass
 
@@ -221,19 +235,22 @@ def km_from_string(s=''):
     set_pid()
     return km
 
-def echo(arg,style="Question"):
+
+def echo(arg, style="Question"):
     try:
         vim.command("echohl %s" % style)
-        vim.command("echom \"%s\"" % arg.replace('\"','\\\"'))
+        vim.command("echom \"%s\"" % arg.replace('\"', '\\\"'))
         vim.command("echohl None")
     except vim.error:
         print("-- %s" % arg)
 
+
 def disconnect():
     "disconnect kernel manager"
     # XXX: make a prompt here if this km owns the kernel
     pass
 
+
 def get_doc(word, level=0):
     if kc is None:
         return ["Not connected to IPython, cannot query: %s" % word]
@@ -242,15 +259,20 @@ def get_doc(word, level=0):
     # get around unicode problems when interfacing with vim
     return [d.encode(vim_encoding) for d in doc]
 
+
 import re
+
 # from http://serverfault.com/questions/71285/in-centos-4-4-how-can-i-strip-escape-sequences-from-a-text-file
 strip = re.compile('\x1B\[([0-9]{1,2}(;[0-9]{1,2})?)?[m|K]')
+
+
 def strip_color_escapes(s):
-    return strip.sub('',s)
+    return strip.sub('', s)
+
 
 def get_doc_msg(msg_id):
-    n = 13 # longest field name (empirically)
-    b=[]
+    n = 13  # longest field name (empirically)
+    b = []
     try:
         content = get_child_msg(msg_id)['content']
     except Empty:
@@ -267,36 +289,39 @@ def get_doc_msg(msg_id):
             for line in text.split('\n'):
                 b.append(strip_color_escapes(line).rstrip())
             return b
-        except KeyError:    # no text/plain key
+        except KeyError:  # no text/plain key
             return b
 
-    for field in ['type_name','base_class','string_form','namespace',
-            'file','length','definition','source','docstring']:
-        c = content.get(field,None)
+    for field in [
+            'type_name', 'base_class', 'string_form', 'namespace', 'file',
+            'length', 'definition', 'source', 'docstring'
+    ]:
+        c = content.get(field, None)
         if c:
             if field in ['definition']:
                 c = strip_color_escapes(c).rstrip()
-            s = field.replace('_',' ').title()+':'
+            s = field.replace('_', ' ').title() + ':'
             s = s.ljust(n)
-            if c.find('\n')==-1:
-                b.append(s+c)
+            if c.find('\n') == -1:
+                b.append(s + c)
             else:
                 b.append(s)
                 b.extend(c.splitlines())
     return b
 
+
 def get_doc_buffer(level=0):
     # empty string in case vim.eval return None
-    vim.command("let isk_save = &isk") # save iskeyword list
+    vim.command("let isk_save = &isk")  # save iskeyword list
     vim.command("let &isk = '@,48-57,_,192-255,.'")
     word = vim.eval('expand("<cword>")') or ''
-    vim.command("let &isk = isk_save") # restore iskeyword list
+    vim.command("let &isk = isk_save")  # restore iskeyword list
     doc = get_doc(word, level)
-    if len(doc) ==0:
-        echo(repr(word)+" not found","Error")
+    if len(doc) == 0:
+        echo(repr(word) + " not found", "Error")
         return
     # documentation buffer name is same as the query made to ipython
-    vim.command('new '+word)
+    vim.command('new ' + word)
     vim.command('setlocal modifiable noro')
     # doc window quick quit keys: 'q' and 'escape'
     vim.command('nnoremap <buffer> q :q<CR>')
@@ -311,7 +336,7 @@ def get_doc_buffer(level=0):
     vim.command('setlocal nomodified bufhidden=wipe')
     #vim.command('setlocal previewwindow nomodifiable nomodified ro')
     #vim.command('set previewheight=%d'%len(b))# go to previous window
-    vim.command('resize %d'%len(b))
+    vim.command('resize %d' % len(b))
     #vim.command('pcl')
     #vim.command('pedit doc')
     #vim.command('normal! ') # go to previous window
@@ -322,6 +347,7 @@ def get_doc_buffer(level=0):
         # use Python syntax highlighting
         vim.command('setlocal syntax=python')
 
+
 def ipy_complete(base, current_line, pos):
     # pos is the location of the start of base, add the length
     # to get the completion position
@@ -330,7 +356,7 @@ def ipy_complete(base, current_line, pos):
     try:
         m = get_child_msg(msg_id)
         matches = m['content']['matches']
-        matches.insert(0,base) # the "no completion" version
+        matches.insert(0, base)  # the "no completion" version
         # we need to be careful with unicode, because we can have unicode
         # completions for filenames (for the %run magic, for example). So the next
         # line will fail on those:
@@ -342,6 +368,7 @@ def ipy_complete(base, current_line, pos):
         echo("no reply from IPython kernel")
         return ['']
 
+
 def vim_ipython_is_open():
     """
     Helper function to let us know if the vim-ipython shell is currently
@@ -371,6 +398,7 @@ def dehtml(text):
         '''This parser analyzes input text, removes HTML tags such as
         <p>, <br>, <ul>, <li> etc and returns properly formatted texts.
         '''
+
         def __init__(self):
             HTMLParser.__init__(self)
             self.__text = []
@@ -423,38 +451,43 @@ def update_subchannel_msgs(debug=False, force=False):
         return False
     msgs = kc.iopub_channel.get_msgs()
     b = vim.current.buffer
-    startedin_vimipython = vim.eval('@%')=='vim-ipython'
+    startedin_vimipython = vim.eval('@%') == 'vim-ipython'
     if not startedin_vimipython:
         # switch to preview window
-        vim.command(
-            "try"
-            "|silent! wincmd P"
-            "|catch /^Vim\%((\a\+)\)\=:E441/"
-            "|silent pedit +set\ ma vim-ipython"
-            "|silent! wincmd P"
-            "|endtry")
+        vim.command("try"
+                    "|silent! wincmd P"
+                    "|catch /^Vim\%((\a\+)\)\=:E441/"
+                    "|silent pedit +set\ ma vim-ipython"
+                    "|silent! wincmd P"
+                    "|endtry")
         # if the current window is called 'vim-ipython'
-        if vim.eval('@%')=='vim-ipython':
+        if vim.eval('@%') == 'vim-ipython':
             # set the preview window height to the current height
             vim.command("set pvh=" + vim.eval('winheight(0)'))
         else:
             # close preview window, it was something other than 'vim-ipython'
             vim.command("pcl")
             vim.command("silent pedit +set\ ma vim-ipython")
-            vim.command("wincmd P") #switch to preview window
+            vim.command("wincmd P")  #switch to preview window
             # subchannel window quick quit key 'q'
             vim.command('nnoremap <buffer> q :q<CR>')
             vim.command("set bufhidden=hide buftype=nofile ft=python")
-            vim.command("setlocal nobuflisted") # don't come up in buffer lists
-            vim.command("setlocal nonumber") # no line numbers, we have in/out nums
-            vim.command("setlocal noswapfile") # no swap file (so no complaints cross-instance)
+            vim.command("setlocal nobuflisted")  # don't come up in buffer lists
+            vim.command(
+                "setlocal nonumber")  # no line numbers, we have in/out nums
+            vim.command("setlocal noswapfile"
+                       )  # no swap file (so no complaints cross-instance)
             # make shift-enter and control-enter in insert mode behave same as in ipython notebook
             # shift-enter send the current line, control-enter send the line
             # but keeps it around for further editing.
-            vim.command("inoremap <buffer> <s-Enter> <esc>dd:python run_command('''<C-r>\"''')<CR>i")
+            vim.command(
+                "inoremap <buffer> <s-Enter> <esc>dd:python run_command('''<C-r>\"''')<CR>i"
+            )
             # pkddA: paste, go up one line which is blank after run_command,
             # delete it, and then back to insert mode
-            vim.command("inoremap <buffer> <c-Enter> <esc>dd:python run_command('''<C-r>\"''')<CR>pkddA")
+            vim.command(
+                "inoremap <buffer> <c-Enter> <esc>dd:python run_command('''<C-r>\"''')<CR>pkddA"
+            )
             # ctrl-C gets sent to the IPython process as a signal on POSIX
             vim.command("noremap <buffer>  :IPythonInterrupt<cr>")
 
@@ -462,12 +495,19 @@ def update_subchannel_msgs(debug=False, force=False):
     # QtConsole In[] is blue, but I prefer the oldschool green
     # since it makes the vim-ipython 'shell' look like the holidays!
     colors = status_prompt_colors
-    vim.command("hi IPyPromptIn ctermfg=%s guifg=%s" % (colors['in_ctermfg'], colors['in_guifg']))
-    vim.command("hi IPyPromptOut ctermfg=%s guifg=%s" % (colors['out_ctermfg'], colors['out_guifg']))
-    vim.command("hi IPyPromptOut2 ctermfg=%s guifg=%s" % (colors['out2_ctermfg'], colors['out2_guifg']))
-    in_expression = vim_regex_escape(status_prompt_in % {'line': 999}).replace('999', '[ 0-9]*')
+    vim.command("hi IPyPromptIn ctermfg=%s guifg=%s" %
+                (colors['in_ctermfg'], colors['in_guifg']))
+    vim.command("hi IPyPromptOut ctermfg=%s guifg=%s" %
+                (colors['out_ctermfg'], colors['out_guifg']))
+    vim.command("hi IPyPromptOut2 ctermfg=%s guifg=%s" %
+                (colors['out2_ctermfg'], colors['out2_guifg']))
+    in_expression = vim_regex_escape(status_prompt_in % {
+        'line': 999
+    }).replace('999', '[ 0-9]*')
     vim.command("syn match IPyPromptIn /^%s/" % in_expression)
-    out_expression = vim_regex_escape(status_prompt_out % {'line': 999}).replace('999', '[ 0-9]*')
+    out_expression = vim_regex_escape(status_prompt_out % {
+        'line': 999
+    }).replace('999', '[ 0-9]*')
     vim.command("syn match IPyPromptOut /^%s/" % out_expression)
     vim.command("syn match IPyPromptOut2 /^\\.\\.\\.* /")
     b = vim.current.buffer
@@ -488,7 +528,7 @@ def update_subchannel_msgs(debug=False, force=False):
             # also echoing the message to the status bar
             try:
                 s = strip_color_escapes(m['content']['data'])
-            except KeyError:    # changed in IPython 3.0.0
+            except KeyError:  # changed in IPython 3.0.0
                 s = strip_color_escapes(m['content']['text'])
         elif header == 'pyout' or header == 'execute_result':
             s = status_prompt_out % {'line': m['content']['execution_count']}
@@ -516,14 +556,14 @@ def update_subchannel_msgs(debug=False, force=False):
             s += m['content']['code'].rstrip().replace('\n', '\n' + dots)
         elif header == 'pyerr' or header == 'error':
             c = m['content']
-            s = "\n".join(map(strip_color_escapes,c['traceback']))
+            s = "\n".join(map(strip_color_escapes, c['traceback']))
             s += c['ename'] + ":" + c['evalue']
 
         if s.find('\n') == -1:
             # somewhat ugly unicode workaround from
             # http://vim.1045645.n5.nabble.com/Limitations-of-vim-python-interface-with-respect-to-character-encodings-td1223881.html
-            if isinstance(s,unicode):
-                s=s.encode(vim_encoding)
+            if isinstance(s, unicode):
+                s = s.encode(vim_encoding)
             b.append(s)
         else:
             try:
@@ -536,11 +576,12 @@ def update_subchannel_msgs(debug=False, force=False):
         if b[-1] != '':
             b.append([''])
     if update_occured or force:
-        vim.command('normal! G') # go to the end of the file
+        vim.command('normal! G')  # go to the end of the file
     if not startedin_vimipython:
-        vim.command('normal! p') # go back to where you were
+        vim.command('normal! p')  # go back to where you were
     return update_occured
 
+
 def get_child_msg(msg_id):
     # XXX: message handling should be split into its own process in the future
     while True:
@@ -550,10 +591,11 @@ def get_child_msg(msg_id):
             break
         else:
             #got a message, but not the one we were looking for
-            echo('skipping a message on shell_channel','WarningMsg')
+            echo('skipping a message on shell_channel', 'WarningMsg')
     return m
 
-def print_prompt(prompt,msg_id=None):
+
+def print_prompt(prompt, msg_id=None):
     """Print In[] or In[42] style messages"""
     global show_execution_count
     if show_execution_count and msg_id:
@@ -561,27 +603,37 @@ def print_prompt(prompt,msg_id=None):
         try:
             child = get_child_msg(msg_id)
             count = child['content']['execution_count']
-            echo("In[%d]: %s" %(count,prompt))
+            echo("In[%d]: %s" % (count, prompt))
         except Empty:
             echo("In[]: %s (no reply from IPython kernel)" % prompt)
     else:
         echo("In[]: %s" % prompt)
 
-def with_subchannel(f,*args):
+
+def with_subchannel(f, *args):
     "conditionally monitor subchannel"
+
     def f_with_update(*args):
         try:
             f(*args)
             if monitor_subchannel:
                 update_subchannel_msgs(force=True)
-        except AttributeError: #if kc is None
+        except AttributeError:  #if kc is None
             echo("not connected to IPython", 'Error')
+
     return f_with_update
 
+
 @with_subchannel
 def run_this_file():
-    msg_id = send('%%run %s %s' % (run_flags, repr(vim.current.buffer.name),))
-    print_prompt("In[]: %%run %s %s" % (run_flags, repr(vim.current.buffer.name)),msg_id)
+    msg_id = send('%%run %s %s' % (
+        run_flags,
+        repr(vim.current.buffer.name),
+    ))
+    print_prompt(
+        "In[]: %%run %s %s" % (run_flags, repr(vim.current.buffer.name)),
+        msg_id)
+
 
 @with_subchannel
 def run_this_line(dedent=False):
@@ -592,8 +644,8 @@ def run_this_line(dedent=False):
         # intercept question mark queries -- move to the word just before the
         # question mark and call the get_doc_buffer on it
         w = vim.current.window
-        original_pos =  w.cursor
-        new_pos = (original_pos[0], vim.current.line.index('?')-1)
+        original_pos = w.cursor
+        new_pos = (original_pos[0], vim.current.line.index('?') - 1)
         w.cursor = new_pos
         if line.rstrip().endswith('??'):
             # double question mark should display source
@@ -609,16 +661,18 @@ def run_this_line(dedent=False):
     msg_id = send(line)
     print_prompt(line, msg_id)
 
+
 @with_subchannel
 def run_command(cmd):
     msg_id = send(cmd)
     print_prompt(cmd, msg_id)
 
+
 @with_subchannel
 def run_these_lines(dedent=False):
     r = vim.current.range
     if dedent:
-        lines = list(vim.current.buffer[r.start:r.end+1])
+        lines = list(vim.current.buffer[r.start:r.end + 1])
         nonempty_lines = [x for x in lines if x.strip()]
         if not nonempty_lines:
             return
@@ -626,7 +680,7 @@ def run_these_lines(dedent=False):
         leading = len(first_nonempty) - len(first_nonempty.lstrip())
         lines = "\n".join(x[leading:] for x in lines)
     else:
-        lines = "\n".join(vim.current.buffer[r.start:r.end+1])
+        lines = "\n".join(vim.current.buffer[r.start:r.end + 1])
     msg_id = send(lines)
     #alternative way of doing this in more recent versions of ipython
     #but %paste only works on the local machine
@@ -639,8 +693,8 @@ def run_these_lines(dedent=False):
 
     #vim lines start with 1
     #print("lines %d-%d sent to ipython"% (r.start+1,r.end+1))
-    prompt = "lines %d-%d "% (r.start+1,r.end+1)
-    print_prompt(prompt,msg_id)
+    prompt = "lines %d-%d " % (r.start + 1, r.end + 1)
+    print_prompt(prompt, msg_id)
 
 
 def set_pid():
@@ -652,8 +706,8 @@ def set_pid():
 
     try:
         msg_id = send(lines, silent=True, user_variables=['_pid'])
-    except TypeError: # change in IPython 3.0+
-        msg_id = send(lines, silent=True, user_expressions={'_pid':'_pid'})
+    except TypeError:  # change in IPython 3.0+
+        msg_id = send(lines, silent=True, user_expressions={'_pid': '_pid'})
 
     # wait to get message back from kernel
     try:
@@ -663,12 +717,13 @@ def set_pid():
         return
     try:
         pid = int(child['content']['user_variables']['_pid'])
-    except TypeError: # change in IPython 1.0.dev moved this out
-        pid = int(child['content']['user_variables']['_pid']['data']['text/plain'])
-    except KeyError:    # change in IPython 3.0+
+    except TypeError:  # change in IPython 1.0.dev moved this out
+        pid = int(
+            child['content']['user_variables']['_pid']['data']['text/plain'])
+    except KeyError:  # change in IPython 3.0+
         pid = int(
             child['content']['user_expressions']['_pid']['data']['text/plain'])
-    except KeyError: # change in IPython 1.0.dev moved this out
+    except KeyError:  # change in IPython 1.0.dev moved this out
         echo("Could not get PID information, kernel not running Python?")
     return pid
 
@@ -678,6 +733,7 @@ def terminate_kernel_hack():
     import signal
     interrupt_kernel_hack(signal.SIGTERM)
 
+
 def interrupt_kernel_hack(signal_to_send=None):
     """
     Sends the interrupt signal to the remote kernel.  This side steps the
@@ -685,8 +741,8 @@ def interrupt_kernel_hack(signal_to_send=None):
     Only works on posix.
     """
     global pid
-    import signal
     import os
+    import signal
     if pid is None:
         # Avoid errors if we couldn't get pid originally,
         # by trying to obtain it now
@@ -698,20 +754,24 @@ def interrupt_kernel_hack(signal_to_send=None):
     if not signal_to_send:
         signal_to_send = signal.SIGINT
 
-    echo("KeyboardInterrupt (sent to ipython: pid " +
-        "%i with signal %s)" % (pid, signal_to_send),"Operator")
+    echo(
+        "KeyboardInterrupt (sent to ipython: pid " + "%i with signal %s)" %
+        (pid, signal_to_send), "Operator")
     try:
         os.kill(pid, int(signal_to_send))
     except OSError:
         echo("unable to kill pid %d" % pid)
         pid = None
 
+
 def dedent_run_this_line():
     run_this_line(True)
 
+
 def dedent_run_these_lines():
     run_these_lines(True)
 
+
 #def set_this_line():
 #    # not sure if there's a way to do this, since we have multiple clients
 #    send("get_ipython().shell.set_next_input(\'%s\')" % vim.current.line.replace("\'","\\\'"))
@@ -721,9 +781,10 @@ def dedent_run_these_lines():
 
 def toggle_reselect():
     global reselect
-    reselect=not reselect
+    reselect = not reselect
     print("F9 will%sreselect lines after sending to ipython" %
-            (reselect and " " or " not "))
+          (reselect and " " or " not "))
+
 
 #def set_breakpoint():
 #    send("__IP.InteractiveTB.pdb.set_break('%s',%d)" % (vim.current.buffer.name,
@@ -745,4 +806,3 @@ def toggle_reselect():
 #    send(' __IP.InteractiveTB.pdb.run(\'execfile("%s")\')' % (vim.current.buffer.name,))
 #    #send('run -d %s' % (vim.current.buffer.name,))
 #    echo("In[]: run -d %s (using pdb)" % vim.current.buffer.name)
-
