@@ -11,7 +11,8 @@ def bash(script, args="", **kwargs):
     """Execute specified script using bash. This action accepts common action arguments such as
     input, active, workdir, docker_image and args. In particular, content of one or more files
     specified by option input would be prepended before the specified script."""
-    return SoS_ExecuteScript(script, ["/bin/bash", "bash"], ".sh", args).run(**kwargs)
+    return SoS_ExecuteScript(script, ["/bin/bash", "bash"], ".sh",
+                             args).run(**kwargs)
 
 
 @SoS_Action(acceptable_args=["script", "args"])
@@ -19,7 +20,8 @@ def csh(script, args="", **kwargs):
     """Execute specified script using csh. This action accepts common action arguments such as
     input, active, workdir, docker_image and args. In particular, content of one or more files
     specified by option input would be prepended before the specified script."""
-    return SoS_ExecuteScript(script, ["/bin/csh", "csh"], ".csh", args).run(**kwargs)
+    return SoS_ExecuteScript(script, ["/bin/csh", "csh"], ".csh",
+                             args).run(**kwargs)
 
 
 @SoS_Action(acceptable_args=["script", "args"])
@@ -27,7 +29,8 @@ def tcsh(script, args="", **kwargs):
     """Execute specified script using tcsh. This action accepts common action arguments such as
     input, active, workdir, docker_image and args. In particular, content of one or more files
     specified by option input would be prepended before the specified script."""
-    return SoS_ExecuteScript(script, ["/bin/tcsh", "tcsh"], ".sh", args).run(**kwargs)
+    return SoS_ExecuteScript(script, ["/bin/tcsh", "tcsh"], ".sh",
+                             args).run(**kwargs)
 
 
 @SoS_Action(acceptable_args=["script", "args"])
@@ -35,7 +38,8 @@ def zsh(script, args="", **kwargs):
     """Execute specified script using zsh. This action accepts common action arguments such as
     input, active, workdir, docker_image and args. In particular, content of one or more files
     specified by option input would be prepended before the specified script."""
-    return SoS_ExecuteScript(script, ["/bin/zsh", "zsh"], ".zsh", args).run(**kwargs)
+    return SoS_ExecuteScript(script, ["/bin/zsh", "zsh"], ".zsh",
+                             args).run(**kwargs)
 
 
 @SoS_Action(acceptable_args=["script", "args"])
@@ -43,4 +47,5 @@ def sh(script, args="", **kwargs):
     """Execute specified script using sh. This action accepts common action arguments such as
     input, active, workdir, docker_image and args. In particular, content of one or more files
     specified by option input would be prepended before the specified script."""
-    return SoS_ExecuteScript(script, ["/bin/sh", "sh"], ".sh", args).run(**kwargs)
+    return SoS_ExecuteScript(script, ["/bin/sh", "sh"], ".sh",
+                             args).run(**kwargs)
