@@ -21,9 +21,8 @@ def python2(script, args="", **kwargs):
     not exist. This action accepts common action arguments such as
     input, active, workdir, docker_image and args. In particular, content of one or more files
     specified by option input would be prepended before the specified script."""
-    return SoS_ExecuteScript(
-        script, ["python2", "python2.7", "python"], ".py", args
-    ).run(**kwargs)
+    return SoS_ExecuteScript(script, ["python2", "python2.7", "python"], ".py",
+                             args).run(**kwargs)
 
 
 @SoS_Action(acceptable_args=["script", "args"])
@@ -32,4 +31,5 @@ def python3(script, args="", **kwargs):
     not exist. This action accepts common action arguments such as
     input, active, workdir, docker_image and args. In particular, content of one or more files
     specified by option input would be prepended before the specified script."""
-    return SoS_ExecuteScript(script, ["python3", "python"], ".py", args).run(**kwargs)
+    return SoS_ExecuteScript(script, ["python3", "python"], ".py",
+                             args).run(**kwargs)
