@@ -7,39 +7,25 @@
 # Utility functions used by various executors.
 #
 import os
-import sys
 import re
-import psutil
+import sys
 import traceback
-
-from typing import Any
 from collections.abc import Sequence
 from io import StringIO
 from tokenize import generate_tokens
+from typing import Any
+from secrets import token_hex
+
+import psutil
 
-from .targets import (
-    RemovedTarget,
-    file_target,
-    sos_targets,
-    sos_step,
-    path,
-    dynamic,
-    sos_variable,
-    RuntimeInfo,
-    textMD5,
-)
-from .utils import (
-    env,
-    Error,
-    format_HHMMSS,
-    expand_size,
-    load_config_files,
-    get_traceback,
-)
-from .eval import SoS_eval, stmtHash, analyze_global_statements
-from .tasks import TaskParams
-from .syntax import SOS_TAG
 from .controller import request_answer_from_controller
+from .eval import SoS_eval, analyze_global_statements, stmtHash
+from .syntax import SOS_TAG
+from .targets import (RemovedTarget, RuntimeInfo, dynamic, file_target,
+                      sos_step, sos_targets, sos_variable)
+from .tasks import TaskParams
+from .utils import (Error, env, expand_size, format_HHMMSS, get_traceback,
+                    load_config_files, textMD5)
 
 
 class ExecuteError(Error):
@@ -58,9 +44,9 @@ class ExecuteError(Error):
         if not lines:
             short_line = ""
         else:
-            short_line = (
-                "[" + (lines[0][:40] if len(lines[0]) > 40 else lines[0]) + "]:"
-            )
+            short_line = ("[" +
+                          (lines[0][:40] if len(lines[0]) > 40 else lines[0]) +
+                          "]:")
         self.errors.append(short_line)
         self.traces.append(get_traceback())
         newline = "\n" if self.message else ""
@@ -74,14 +60,13 @@ def __null_func__(*args, **kwargs) -> Any:
     def _flatten(x):
         if isinstance(x, str):
             return [x]
-        elif isinstance(x, sos_targets):
+        if isinstance(x, sos_targets):
             return [x]
-        elif isinstance(x, Sequence):
+        if isinstance(x, Sequence):
             return sum((_flatten(k) for k in x), [])
-        elif hasattr(x, "__flattenable__"):
+        if hasattr(x, "__flattenable__"):
             return _flatten(x.flatten())
-        else:
-            return [x]
+        return [x]
 
     return _flatten(args), kwargs
 
@@ -101,17 +86,19 @@ def __output_from__(
     elif isinstance(steps, Sequence):
         steps = list(steps)
     else:
-        raise ValueError(f"Unacceptable value of input prameter from: {steps} provided")
+        raise ValueError(
+            f"Unacceptable value of input prameter from: {steps} provided")
     #
     for step in steps:
         if isinstance(step, int):
             if step == -1:
                 # this refers to the last step of a forward style workflow
-                if "__last_step__" in env.sos_dict and env.sos_dict["__last_step__"]:
+                if "__last_step__" in env.sos_dict and env.sos_dict[
+                        "__last_step__"]:
                     step = env.sos_dict["__last_step__"]
                 else:
                     raise ValueError(
-                        f"output_from(-1) is called for a step without previous step"
+                        "output_from(-1) is called for a step without previous step"
                     )
             elif "_" in env.sos_dict["step_name"]:
                 step = f"{env.sos_dict['step_name'].rsplit('_', 1)[0]}_{step}"
@@ -169,11 +156,18 @@ def clear_output(output=None):
     Remove file targets in `_output` when a step fails to complete
     """
     for target in env.sos_dict["_output"] if output is None else output:
-        if isinstance(target, file_target) and target.exists():
+        if isinstance(target, file_target):
             try:
+                #new_name = target + '.' + token_hex(3) + '.bak'
+                #target.rename(new_name)
+                #env.logger.debug(
+                #    f"{target} removed to {new_name} due to failed step.")
                 target.unlink()
-            except Exception as e:
-                env.logger.warning(f"Failed to remove {target}: {e}")
+                (target + '.md5').unlink()
+            except Exception:
+                # ok if file does not exist (FileNotfoundError)
+                pass
+
 
 
 def get_traceback_msg(e):
@@ -184,12 +178,10 @@ def get_traceback_msg(e):
         if st.filename.startswith("script_"):
             code = stmtHash.script(st.filename)
             line_number = st.lineno
-            code = "\n".join(
-                [
-                    f'{"---->" if i+1 == line_number else "     "} {x.rstrip()}'
-                    for i, x in enumerate(code.splitlines())
-                ][max(line_number - 3, 0) : line_number + 3]
-            )
+            code = "\n".join([
+                f'{"---->" if i+1 == line_number else "     "} {x.rstrip()}'
+                for i, x in enumerate(code.splitlines())
+            ][max(line_number - 3, 0):line_number + 3])
             msg += f"""\
 {st.filename} in {st.name}
 {code}
@@ -201,8 +193,7 @@ def get_traceback_msg(e):
 {error_class:42}Traceback (most recent call last)
 {msg}
 {error_class}: {detail}"""
-    else:
-        return f"{error_class}: {detail}"
+    return f"{error_class}: {detail}"
 
 
 def prepare_env(gdef="", gvars={}, extra_vars={}, host="localhost"):
@@ -223,29 +214,29 @@ def prepare_env(gdef="", gvars={}, extra_vars={}, host="localhost"):
     if "CONFIG" not in env.sos_dict:
         # if this is in sos notebook
         load_config_files()
-    if (
-        "hosts" not in env.sos_dict["CONFIG"]
-        and "localhost" not in env.sos_dict["CONFIG"]
-    ):
+    if ("hosts" not in env.sos_dict["CONFIG"] and
+            "localhost" not in env.sos_dict["CONFIG"]):
         env.sos_dict["CONFIG"]["localhost"] = "localhost"
         env.sos_dict["CONFIG"]["hosts"] = {
-            "localhost": {"paths": {}, "address": "localhost"}
+            "localhost": {
+                "paths": {},
+                "address": "localhost"
+            }
         }
     # expose `paths` of localhost
     if host == "localhost":
         if "localhost" in env.sos_dict["CONFIG"]:
-            if (
-                "hosts" not in env.sos_dict["CONFIG"]
-                or env.sos_dict["CONFIG"]["localhost"]
-                not in env.sos_dict["CONFIG"]["hosts"]
-            ):
+            if ("hosts" not in env.sos_dict["CONFIG"] or
+                    env.sos_dict["CONFIG"]["localhost"]
+                    not in env.sos_dict["CONFIG"]["hosts"]):
                 env.logger.warning(
                     f"Localhost {env.sos_dict['CONFIG']['localhost']} is not defined in CONFIG['hosts']"
                 )
-                env.sos_dict["CONFIG"]["hosts"][env.sos_dict["CONFIG"]["localhost"]] = {
-                    "paths": {},
-                    "address": "localhost",
-                }
+                env.sos_dict["CONFIG"]["hosts"][env.sos_dict["CONFIG"]
+                                                ["localhost"]] = {
+                                                    "paths": {},
+                                                    "address": "localhost",
+                                                }
             env.sos_dict.set("__host__", env.sos_dict["CONFIG"]["localhost"])
         else:
             if "hosts" in env.sos_dict["CONFIG"]:
@@ -259,10 +250,8 @@ def prepare_env(gdef="", gvars={}, extra_vars={}, host="localhost"):
                 env.sos_dict["CONFIG"]["hosts"]["localhost"]["paths"] = {}
             env.sos_dict.set("__host__", "localhost")
     else:
-        if (
-            "hosts" not in env.sos_dict["CONFIG"]
-            or host not in env.sos_dict["CONFIG"]["hosts"]
-        ):
+        if ("hosts" not in env.sos_dict["CONFIG"] or
+                host not in env.sos_dict["CONFIG"]["hosts"]):
             raise RuntimeError(
                 f"Remote host {host} is not defined in CONFIG['hosts']. Available ones are {env.sos_dict['CONFIG']['hosts'].keys()}"
             )
@@ -270,6 +259,7 @@ def prepare_env(gdef="", gvars={}, extra_vars={}, host="localhost"):
 
 
 def statementMD5(stmts):
+
     def _get_tokens(statement):
         return [
             x[1]
@@ -288,8 +278,8 @@ def create_task(global_def, global_vars, task_stmt, task_params):
     # env.sos_dict.set('_runtime', {})
     if task_params:
         args, kwargs = SoS_eval(
-            f"__null_func__({task_params})", extra_dict={"__null_func__": __null_func__}
-        )
+            f"__null_func__({task_params})",
+            extra_dict={"__null_func__": __null_func__})
         if args:
             raise RuntimeError(
                 f'Only keyword arguments are accepted for task statement: "{task_params}" provided'
@@ -310,12 +300,6 @@ def create_task(global_def, global_vars, task_stmt, task_params):
     env.sos_dict["_runtime"]["verbosity"] = env.verbosity
     env.sos_dict["_runtime"]["sig_mode"] = env.config.get("sig_mode", "default")
     env.sos_dict["_runtime"]["run_mode"] = env.config.get("run_mode", "run")
-    #if "workdir" not in env.sos_dict["_runtime"]:
-    #    env.sos_dict["_runtime"]["workdir"] = path.cwd().shrink()
-    # elif "TASK" in env.config["SOS_DEBUG"] or "ALL" in env.config["SOS_DEBUG"]:
-    #     env.log_to_file(
-    #         "TASK", f'Using specified workdir {env.sos_dict["_runtime"]["workdir"]}'
-    #     )
 
     # 1324
     env.sos_dict["_runtime"].update(env.config.get("queue_args", {}))
@@ -334,8 +318,7 @@ def create_task(global_def, global_vars, task_stmt, task_params):
             "step_name",
             "_runtime",
             "__signature_vars__",
-        }
-    )
+        })
 
     task_tags = [
         env.sos_dict["step_name"],
@@ -356,7 +339,8 @@ def create_task(global_def, global_vars, task_stmt, task_params):
             if not SOS_TAG.match(tag):
                 new_tag = re.sub(r"[^\w_.-]", "", tag)
                 if new_tag:
-                    env.logger.warning(f'Invalid tag "{tag}" is added as "{new_tag}"')
+                    env.logger.warning(
+                        f'Invalid tag "{tag}" is added as "{new_tag}"')
                     task_tags.append(new_tag)
                 else:
                     env.logger.warning(f'Invalid tag "{tag}" is ignored')
@@ -365,7 +349,7 @@ def create_task(global_def, global_vars, task_stmt, task_params):
 
     # save task to a file
     taskdef = TaskParams(
-        name="{} (index={})".format(env.sos_dict["step_name"], env.sos_dict["_index"]),
+        name=f"{env.sos_dict['step_name']} (index={env.sos_dict['_index']})",
         global_def=(global_def, global_vars),
         task=task_stmt,  # task
         sos_dict=task_vars,
@@ -373,7 +357,7 @@ def create_task(global_def, global_vars, task_stmt, task_params):
     )
     # if no output (thus no signature)
     # temporarily create task signature to obtain sig_id
-    task_id = RuntimeInfo(
+    task_id = 't' + RuntimeInfo(
         statementMD5([task_stmt]),
         task_vars["_input"],
         task_vars["_output"],
@@ -426,7 +410,8 @@ def reevaluate_output():
     # handle dynamic args
     args = [x.resolve() if isinstance(x, dynamic) else x for x in args]
     kwargs = {
-        x: (y.resolve() if isinstance(y, dynamic) else y) for x, y in kwargs.items()
+        x: (y.resolve() if isinstance(y, dynamic) else y)
+        for x, y in kwargs.items()
     }
     return sos_targets(*args, **kwargs, _verify_existence=True)
 
@@ -441,10 +426,9 @@ def validate_step_sig(sig):
                 f'``{env.sos_dict["step_name"]}`` (index={env.sos_dict["_index"]}) is ``ignored`` due to saved signature'
             )
             return matched
-        else:
-            env.logger.debug(f"Signature mismatch: {matched}")
-            return {}
-    elif env.config["sig_mode"] == "assert":
+        env.logger.debug(f"Signature mismatch: {matched}")
+        return {}
+    if env.config["sig_mode"] == "assert":
         matched = sig.validate()
         if isinstance(matched, str):
             raise RuntimeError(f"Signature mismatch: {matched}")
@@ -452,7 +436,7 @@ def validate_step_sig(sig):
             f'Substep ``{env.sos_dict["step_name"]}`` (index={env.sos_dict["_index"]}) is ``ignored`` with matching signature'
         )
         return matched
-    elif env.config["sig_mode"] == "build":
+    if env.config["sig_mode"] == "build":
         # build signature require existence of files
         if sig.write():
             env.logger.info(
@@ -467,7 +451,8 @@ def validate_step_sig(sig):
     elif env.config["sig_mode"] == "force":
         return {}
     else:
-        raise RuntimeError(f'Unrecognized signature mode {env.config["sig_mode"]}')
+        raise RuntimeError(
+            f'Unrecognized signature mode {env.config["sig_mode"]}')
 
 
 def strip_param_defs(stmt):
@@ -496,6 +481,6 @@ def verify_input(ignore_internal_targets=False):
     for key in ("_input", "_depends"):
         for target in env.sos_dict[key]:
             if not target.target_exists("target") and not (
-                ignore_internal_targets and isinstance(target, (sos_variable, sos_step))
-            ):
+                    ignore_internal_targets and
+                    isinstance(target, (sos_variable, sos_step))):
                 raise RemovedTarget(target)
