@@ -9,9 +9,9 @@ import sys
 
 import pexpect
 
-from .utils import env
-from .targets import path
 from .hosts import Host
+from .targets import path
+from .utils import env
 
 
 def list_queues(cfg, hosts=[], verbosity=1):
@@ -19,8 +19,7 @@ def list_queues(cfg, hosts=[], verbosity=1):
     all_hosts = cfg.get("hosts", [])
     if not all_hosts:
         env.logger.warning(
-            "No remote host or task queue is defined in ~/.sos/hosts.yml."
-        )
+            "No remote host or task queue is defined in ~/.sos/hosts.yml.")
         return
     for host in hosts:
         if host not in all_hosts:
@@ -29,7 +28,8 @@ def list_queues(cfg, hosts=[], verbosity=1):
         ["Alias", "Address", "Queue Type", "Description"],
         ["-----", "-------", "----------", "-----------"],
     ]
-    for host in sorted([x for x in hosts if x in all_hosts] if hosts else all_hosts):
+    for host in sorted([x for x in hosts
+                        if x in all_hosts] if hosts else all_hosts):
         try:
             h = Host(host, start_engine=False, test_connection=False)
         except Exception as e:
@@ -43,15 +43,16 @@ def list_queues(cfg, hosts=[], verbosity=1):
                 if isinstance(cfg["hosts"][host], dict):
                     print("Configuration:")
                     for key in cfg["hosts"][host].keys():
-                        print(f'  {(key + ":").ljust(24)} {cfg["hosts"][host][key]}')
+                        print(
+                            f'  {(key + ":").ljust(24)} {cfg["hosts"][host][key]}'
+                        )
                 print()
             continue
         if verbosity == 0:
             print(h.alias)
         elif verbosity in (1, 2):
             host_description.append(
-                [h.alias, h._host_agent.address, h._engine_type, h.description]
-            )
+                [h.alias, h._host_agent.address, h._engine_type, h.description])
         else:
             print(f"Queue:       {h.alias}")
             print(f"Address:     {h._host_agent.address}")
@@ -65,12 +66,9 @@ def list_queues(cfg, hosts=[], verbosity=1):
     if verbosity in (1, 2):
         width = [(len(x) for x in row) for row in host_description]
         max_width = [max(x) for x in zip(*width)]
-        print(
-            "\n".join(
-                " ".join([t.ljust(w) for t, w in zip(row, max_width)])
-                for row in host_description
-            )
-        )
+        print("\n".join(" ".join([t.ljust(w)
+                                  for t, w in zip(row, max_width)])
+                        for row in host_description))
 
 
 def status_of_queues(cfg, hosts=[], verbosity=1):
@@ -78,8 +76,7 @@ def status_of_queues(cfg, hosts=[], verbosity=1):
     all_hosts = cfg.get("hosts", [])
     if not all_hosts:
         env.logger.warning(
-            "No remote host or task queue is defined in ~/.sos/hosts.yml."
-        )
+            "No remote host or task queue is defined in ~/.sos/hosts.yml.")
         return
     for host in hosts:
         if host not in all_hosts:
@@ -88,7 +85,8 @@ def status_of_queues(cfg, hosts=[], verbosity=1):
         ["Alias", "Address", "Queue Type", "Running", "Pending", "Completed"],
         ["-----", "-------", "----------", "-------", "-------", "---------"],
     ]
-    for host in sorted([x for x in hosts if x in all_hosts] if hosts else all_hosts):
+    for host in sorted([x for x in hosts
+                        if x in all_hosts] if hosts else all_hosts):
         try:
             h = Host(host, start_engine=True)
             status = h._task_engine.query_tasks(tasks=[], verbosity=0)
@@ -105,7 +103,9 @@ def status_of_queues(cfg, hosts=[], verbosity=1):
                 if isinstance(cfg["hosts"][host], dict):
                     print("Configuration:")
                     for key in cfg["hosts"][host].keys():
-                        print(f'  {(key + ":").ljust(24)} {cfg["hosts"][host][key]}')
+                        print(
+                            f'  {(key + ":").ljust(24)} {cfg["hosts"][host][key]}'
+                        )
                 print()
             continue
         status = [x.strip() for x in status.splitlines() if x.strip()]
@@ -116,16 +116,14 @@ def status_of_queues(cfg, hosts=[], verbosity=1):
         if verbosity == 0:
             print(f"{h.alias} {running} {pending} {completed}")
         elif verbosity in (1, 2):
-            host_description.append(
-                [
-                    h.alias,
-                    h._host_agent.address,
-                    h._engine_type,
-                    running,
-                    pending,
-                    completed,
-                ]
-            )
+            host_description.append([
+                h.alias,
+                h._host_agent.address,
+                h._engine_type,
+                running,
+                pending,
+                completed,
+            ])
         else:
             print(f"Queue:       {h.alias}")
             print(f"Address:     {h._host_agent.address}")
@@ -142,12 +140,9 @@ def status_of_queues(cfg, hosts=[], verbosity=1):
     if verbosity in (1, 2):
         width = [(len(x) for x in row) for row in host_description]
         max_width = [max(x) for x in zip(*width)]
-        print(
-            "\n".join(
-                " ".join([t.ljust(w) for t, w in zip(row, max_width)])
-                for row in host_description
-            )
-        )
+        print("\n".join(" ".join([t.ljust(w)
+                                  for t, w in zip(row, max_width)])
+                        for row in host_description))
 
 
 def test_ssh(host):
@@ -161,7 +156,8 @@ def test_scp(host):
     import random
 
     tID = random.randint(1, 100000)
-    task_filename = os.path.join(os.path.expanduser("~"), ".sos", f"test_{tID}.tmp")
+    task_filename = os.path.join(
+        os.path.expanduser("~"), ".sos", f"test_{tID}.tmp")
     with open(task_filename, "w") as test_task:
         test_task.write("test task")
     # test scp
@@ -181,11 +177,11 @@ def test_scp(host):
 def test_cmd(host, cmd):
     # test the execution of sos commands
     try:
-        ret = host.check_call(cmd, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
+        ret = host.check_call(
+            cmd, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
         if ret == 0:
             return "OK"
-        else:
-            return "sos not installed or not accessible on host."
+        return "sos not installed or not accessible on host."
     except Exception as e:
         return str(e)
 
@@ -215,7 +211,8 @@ def test_paths(host):
 
         # test if local directory is writable
         try:
-            with open(os.path.join(local, f".sos_test_{tID}.txt"), "w") as tFile:
+            with open(os.path.join(local, f".sos_test_{tID}.txt"),
+                      "w") as tFile:
                 tFile.write(f"{tID}")
         except Exception:
             return f"Failed to write to mapped directory {local}"
@@ -229,7 +226,8 @@ def test_paths(host):
 
         # the file should be available on remote host
         try:
-            remote_content = host.check_output(f"cat {remote}/.sos_test_{tID}.txt")
+            remote_content = host.check_output(
+                f"cat {remote}/.sos_test_{tID}.txt")
         except Exception as e:
             return (
                 f"Failed to send files under {local} to remote host under {remote}: {e}"
@@ -258,7 +256,8 @@ def test_paths(host):
         os.remove(os.path.join(local, f".sos_test_{tID}.txt"))
         #
         try:
-            remote_content = host.check_output(f"rm {remote}/.sos_test_{tID}.txt")
+            remote_content = host.check_output(
+                f"rm {remote}/.sos_test_{tID}.txt")
         except Exception as e:
             return f"Failed to remove test file on remote host: {e}"
     return "OK"
@@ -282,7 +281,9 @@ def test_shared(host):
             remote_files = host.check_output(f"ls -a {path(remote):q}")
         except Exception:
             return f"Failed to access shared directory {remote} on remote host."
-        remote_files = [x for x in remote_files.splitlines() if x not in (".", "..")]
+        remote_files = [
+            x for x in remote_files.splitlines() if x not in (".", "..")
+        ]
         #
         if sorted(local_files) != sorted(remote_files):
             return f"shared directory {local} has different content on remote host under {remote}"
@@ -312,8 +313,7 @@ def test_queue(host, cmd=None, verbosity=1):
         ssh_res,
         test_scp(h._host_agent) if ssh_res.startswith("OK") else "-",
         test_cmd(h._host_agent, [h.config.get("sos", "sos"), "-h"])
-        if ssh_res.startswith("OK")
-        else "-",
+        if ssh_res.startswith("OK") else "-",
         test_paths(h._host_agent) if ssh_res.startswith("OK") else "-",
         test_shared(h._host_agent) if ssh_res.startswith("OK") else "-",
     ] + ([] if cmd is None else [test_cmd(h._host_agent, cmd)])
@@ -324,14 +324,17 @@ def test_queues(cfg, hosts=[], cmd=None, verbosity=1):
     all_hosts = cfg.get("hosts", [])
     if not all_hosts:
         env.logger.warning(
-            "No remote host or task queue is defined in ~/.sos/hosts.yml."
-        )
+            "No remote host or task queue is defined in ~/.sos/hosts.yml.")
         return
     host_description = [
-        ["Alias", "Address", "Queue Type", "ssh", "scp", "sos", "paths", "shared"]
-        + ([] if cmd is None else [" ".join(cmd)]),
-        ["-----", "-------", "----------", "---", "---", "---", "-----", "------"]
-        + ([] if cmd is None else ["-" * len(" ".join(cmd))]),
+        [
+            "Alias", "Address", "Queue Type", "ssh", "scp", "sos", "paths",
+            "shared"
+        ] + ([] if cmd is None else [" ".join(cmd)]),
+        [
+            "-----", "-------", "----------", "---", "---", "---", "-----",
+            "------"
+        ] + ([] if cmd is None else ["-" * len(" ".join(cmd))]),
     ]
     for host in hosts:
         if host not in all_hosts:
@@ -343,8 +346,7 @@ def test_queues(cfg, hosts=[], cmd=None, verbosity=1):
 
     pool = Pool(min(len(hosts), 10))
     host_description.extend(
-        pool.starmap(test_queue, [(x, cmd, verbosity) for x in hosts])
-    )
+        pool.starmap(test_queue, [(x, cmd, verbosity) for x in hosts]))
     if verbosity == 0:
         # just print succ or self
         for hd in host_description:
@@ -352,21 +354,15 @@ def test_queues(cfg, hosts=[], cmd=None, verbosity=1):
     elif verbosity in (1, 2):
         shortened = host_description[:2]
         for row in host_description[2:]:
-            shortened.append(
-                row[:3]
-                + [
-                    "OK" if x.startswith("OK") else ("-" if x == "-" else "FAIL")
-                    for x in row[3:]
-                ]
-            )
+            shortened.append(row[:3] + [
+                "OK" if x.startswith("OK") else ("-" if x == "-" else "FAIL")
+                for x in row[3:]
+            ])
         width = [(len(x) for x in row) for row in shortened]
         max_width = [max(x) for x in zip(*width)]
-        print(
-            "\n".join(
-                " ".join([t.ljust(w) for t, w in zip(row, max_width)])
-                for row in shortened
-            )
-        )
+        print("\n".join(" ".join([t.ljust(w)
+                                  for t, w in zip(row, max_width)])
+                        for row in shortened))
         if any("FAILED" in row for row in shortened):
             print(
                 '\nUse command "sos remote --test host -v3" to check details of hosts with failed tests.'
@@ -393,17 +389,16 @@ def copy_public_key(host, agent, password):
         if password is None:
             import getpass
 
-            password = getpass.getpass(f"Please enter password for {agent.address}: ")
+            password = getpass.getpass(
+                f"Please enter password for {agent.address}: ")
         cmd = f"scp -P {agent.port if agent.port else 22} {os.path.expanduser('~')}/.ssh/id_rsa.pub {agent.address}:id_rsa.pub.{host}"
         env.logger.info(cmd)
         p = pexpect.spawn(cmd, echo=False)
-        i = p.expect(
-            [
-                "(?i)are you sure you want to continue connecting",
-                "[pP]assword:",
-                pexpect.EOF,
-            ]
-        )
+        i = p.expect([
+            "(?i)are you sure you want to continue connecting",
+            "[pP]assword:",
+            pexpect.EOF,
+        ])
         if i == 0:
             p.sendline("yes")
             p.expect(
@@ -420,7 +415,7 @@ def copy_public_key(host, agent, password):
             i = p.expect(["assword:", pexpect.EOF])
             if i == 0:
                 p.close(force=True)
-                return f"Incorrect password specified (you can try to specify it with command line option --password)"
+                return "Incorrect password specified (you can try to specify it with command line option --password)"
         if i == 2:
             p.close()
             return f"Failed to copy public key to {agent.address}"
@@ -433,13 +428,11 @@ def copy_public_key(host, agent, password):
         cmd = f"ssh {agent.address} -p {agent.port} '[ -d .ssh ] || mkdir .ssh && chmod 700 .ssh; cat id_rsa.pub.{host} >> .ssh/authorized_keys; rm -f id_rsa.pub.{host}'"
         env.logger.info(cmd)
         p = pexpect.spawn(cmd, echo=False)
-        i = p.expect(
-            [
-                "(?i)are you sure you want to continue connecting",
-                "assword:",
-                pexpect.EOF,
-            ]
-        )
+        i = p.expect([
+            "(?i)are you sure you want to continue connecting",
+            "assword:",
+            pexpect.EOF,
+        ])
         if i == 0:
             p.sendline("yes")
             p.expect(
@@ -456,10 +449,10 @@ def copy_public_key(host, agent, password):
             i = p.expect(["assword:", pexpect.EOF])
             if i == 0:
                 p.close(force=True)
-                return f"Incorrect password specified (you can try to specify it with command line option --password)"
+                return "Incorrect password specified (you can try to specify it with command line option --password)"
         elif i != 1:
             p.close()
-            return f"Failed to append public key to .ssh/authorized_keys"
+            return "Failed to append public key to .ssh/authorized_keys"
     except Exception as e:
         p.close()
         return f"Failed to append public key to .ssh/authorized_keys: {e}"
@@ -472,15 +465,13 @@ def create_public_key():
         env.logger.info(cmd)
         p = pexpect.spawn(cmd, echo=False)
         while True:
-            i = p.expect(
-                [
-                    "Enter file in which to save .*",
-                    "Enter passphrase.*",
-                    "Enter same passphrase again:.*",
-                    "Overwrite .*",
-                    pexpect.EOF,
-                ]
-            )
+            i = p.expect([
+                "Enter file in which to save .*",
+                "Enter passphrase.*",
+                "Enter same passphrase again:.*",
+                "Overwrite .*",
+                pexpect.EOF,
+            ])
             if i in (0, 1, 2):
                 p.sendline("")
             elif i == 3:
@@ -489,7 +480,7 @@ def create_public_key():
                 break
     except Exception as e:
         p.close()
-        raise RuntimeError(f"Failed to create a public key: {e}")
+        raise RuntimeError(f"Failed to create a public key: {e}") from e
 
 
 def setup_remote_access(cfg, hosts=[], password="", verbosity=1):
@@ -497,14 +488,12 @@ def setup_remote_access(cfg, hosts=[], password="", verbosity=1):
     all_hosts = cfg.get("hosts", [])
     if not all_hosts and not hosts:
         env.logger.warning(
-            "No remote host or task queue is defined in ~/.sos/hosts.yml."
-        )
+            "No remote host or task queue is defined in ~/.sos/hosts.yml.")
         return
     for host in hosts:
         if host not in all_hosts:
             env.logger.warning(
-                f"Treating undefined host {host} as address of a remote host."
-            )
+                f"Treating undefined host {host} as address of a remote host.")
     # public_key
     public_key = os.path.join(os.path.expanduser("~"), ".ssh", "id_rsa.pub")
 
@@ -523,13 +512,14 @@ def setup_remote_access(cfg, hosts=[], password="", verbosity=1):
                         f"Public key access is already enabled for host ``{host}`` with address ``{host_agent.address}``"
                     )
                     continue
-                elif "Could not resolve hostname" in response:
+                if "Could not resolve hostname" in response:
                     env.logger.error(response)
                     sys.exit(1)
             else:
                 host_agent = Namespace(address=host, port=22)
         except Exception as e:
-            env.logger.error(f"Failed to start set up remote engine for {host}: {e}")
+            env.logger.error(
+                f"Failed to start set up remote engine for {host}: {e}")
             continue
 
         if os.path.isfile(public_key):
@@ -548,32 +538,30 @@ def setup_remote_access(cfg, hosts=[], password="", verbosity=1):
         # file copied, check ssh again.
         if isinstance(host_agent, Namespace):
             host_agent = Host(
-                host, start_engine=False, test_connection=False
-            )._host_agent
+                host, start_engine=False, test_connection=False)._host_agent
         response = test_ssh(host_agent)
         if response.startswith("OK"):
             env.logger.info(
                 f"Public key access is successfully set up for host ``{host}`` with address ``{host_agent.address}``"
             )
             continue
-        else:
-            env.logger.error(
-                f"Failed to connect to {host} after passing public key. Possible problems include permission of .ssh and home directories."
-            )
+        env.logger.error(
+            f"Failed to connect to {host} after passing public key. Possible problems include permission of .ssh and home directories."
+        )
 
 
 def login_host(cfg, host):
     try:
         h = Host(host, start_engine=False)
     except Exception as e:
-        raise ValueError(f"Unrecognized or invalid host {host}: {e}")
+        raise ValueError(f"Unrecognized or invalid host {host}: {e}") from e
 
     address, port = h._host_agent.address, h._host_agent.port
     try:
         env.logger.info(f"Running ``ssh {address} -p {port}``")
         os.execvp("ssh", ["ssh", address, "-p", str(port)])
     except Exception as e:
-        raise RuntimeError(f"Failed to log in to {host}: {e}")
+        raise RuntimeError(f"Failed to log in to {host}: {e}") from e
 
 
 def run_command_on_hosts(cfg, hosts, cmd, verbosity):
@@ -582,8 +570,7 @@ def run_command_on_hosts(cfg, hosts, cmd, verbosity):
         hosts = cfg.get("hosts", [])
     if not hosts:
         env.logger.warning(
-            "No remote host or task queue is defined in ~/.sos/hosts.yml."
-        )
+            "No remote host or task queue is defined in ~/.sos/hosts.yml.")
         return
     for host in hosts:
         # runing command on all hosts
@@ -605,8 +592,7 @@ def push_to_hosts(cfg, hosts, items, verbosity):
         hosts = cfg.get("hosts", [])
     if not hosts:
         env.logger.warning(
-            "No remote host or task queue is defined in ~/.sos/hosts.yml."
-        )
+            "No remote host or task queue is defined in ~/.sos/hosts.yml.")
         return
     for host in hosts:
         try:
@@ -616,15 +602,13 @@ def push_to_hosts(cfg, hosts, items, verbosity):
             #
             sent = h.send_to_host(items)
             #
-            env.logger.info(
-                "{} item{} sent:\n{}".format(
-                    len(sent),
-                    " is" if len(sent) <= 1 else "s are",
-                    "\n".join(
-                        ["{} => {}".format(x, sent[x]) for x in sorted(sent.keys())]
-                    ),
-                )
-            )
+            env.logger.info("{} item{} sent:\n{}".format(
+                len(sent),
+                " is" if len(sent) <= 1 else "s are",
+                "\n".join([
+                    f"{x} => {sent[x]}" for x in sorted(sent.keys())
+                ]),
+            ))
         except Exception as e:
             from .utils import get_traceback
 
@@ -640,8 +624,7 @@ def pull_from_host(cfg, hosts, items, verbosity):
         hosts = cfg.get("hosts", [])
     if not hosts:
         env.logger.warning(
-            "No remote host or task queue is defined in ~/.sos/hosts.yml."
-        )
+            "No remote host or task queue is defined in ~/.sos/hosts.yml.")
         return
     if len(hosts) > 1:
         raise ValueError("Can only pull from a single remote host.")
@@ -652,15 +635,14 @@ def pull_from_host(cfg, hosts, items, verbosity):
         #
         received = host.receive_from_host(items)
         #
-        print(
-            "{} item{} received:\n{}".format(
-                len(received),
-                " is" if len(received) <= 1 else "s are",
-                "\n".join(
-                    ["{} <= {}".format(x, received[x]) for x in sorted(received.keys())]
-                ),
-            )
-        )
+        print("{} item{} received:\n{}".format(
+            len(received),
+            " is" if len(received) <= 1 else "s are",
+            "\n".join([
+                f"{x} <= {received[x]}"
+                for x in sorted(received.keys())
+            ]),
+        ))
     except Exception as e:
         from .utils import get_traceback
 
