@@ -27,9 +27,11 @@ def _load_group(group: str) -> None:
 
             if "Requirement.parse" in str(e):
                 import re
-                from ._version import __version__
+
                 from pkg_resources import parse_version
 
+                from ._version import __version__
+
                 m = re.search(r"Requirement.parse\('sos>=([^)]*)'\)", str(e))
                 if m:
                     if parse_version(__version__) < parse_version(m.group(1)):
@@ -39,9 +41,11 @@ def _load_group(group: str) -> None:
                         continue
             if _name == "run":
                 # this is critical so we print the warning
-                get_logger().warning(f"Failed to load target {_entrypoint.name}: {e}")
+                get_logger().warning(
+                    f"Failed to load target {_entrypoint.name}: {e}")
             else:
-                get_logger().debug(f"Failed to load target {_entrypoint.name}: {e}")
+                get_logger().debug(
+                    f"Failed to load target {_entrypoint.name}: {e}")
 
 
 _load_group("sos_targets")
