@@ -7,15 +7,15 @@ import os
 import shutil
 import subprocess
 import sys
-import time
 import tempfile
+import time
 
+from sos.controller import (request_answer_from_controller,
+                            send_message_to_controller)
 from sos.eval import interpolate
 from sos.targets import path
 from sos.utils import env, pexpect_run
 
-from sos.controller import request_answer_from_controller, send_message_to_controller
-
 #
 # Singularity support
 #
@@ -34,7 +34,7 @@ class SoS_SingularityClient:
 
     def _ensure_singularity(self):
         if not shutil.which('singularity'):
-            raise RuntimeError(f'Command singularity is not found')
+            raise RuntimeError('Command singularity is not found')
 
     def _is_image_avail(self, image):
         # the command will return ID of the image if it exists
@@ -151,7 +151,7 @@ class SoS_SingularityClient:
         self._ensure_singularity()
         if not dest:
             raise ValueError(
-                f'Please specify result of sigularity build with option dest')
+                'Please specify result of sigularity build with option dest')
 
         if os.path.isfile(dest) and not 'force' in kwargs:
             raise ValueError(
@@ -165,7 +165,7 @@ class SoS_SingularityClient:
             else:
                 if not src:
                     raise ValueError(
-                        f'Please specify either a script file as script or a source url with option --src'
+                        'Please specify either a script file as script or a source url with option --src'
                     )
                 file_opt = [dest, src]
 
@@ -203,15 +203,15 @@ class SoS_SingularityClient:
 
             if ret != 0:
                 if script:
-                    debug_script_dir = os.path.join(env.exec_dir, '.sos')
-                    msg = 'The definition has been saved to {}/singularity.def. To reproduce the error please run:\n``{}``'.format(
-                        debug_script_dir, cmd.replace(tempdir,
-                                                      debug_script_dir))
+                    debug_script_dir = os.path.join(
+                        os.path.expanduser('~'), '.sos')
+                    cmd_line = cmd.replace(tempdir,debug_script_dir)
+                    msg = f"The definition has been saved to {debug_script_dir}/singularity.def. To reproduce the error please run:\n``{cmd_line}``"
                     shutil.copy(
                         os.path.join(tempdir, 'Singularityfile'),
                         debug_script_dir)
                 else:
-                    msg = f'To reproduce this error please run \n  {cmd}\nfrom command line'
+                    msg = f"To reproduce this error please run \n  {cmd}\nfrom command line"
                 raise subprocess.CalledProcessError(
                     returncode=ret, cmd=cmd, stderr=msg)
 
@@ -222,25 +222,23 @@ class SoS_SingularityClient:
         if not os.path.isdir(lib_path):
             try:
                 os.makedirs(lib_path, exist_ok=True)
-            except:
+            except Exception as e:
                 raise RuntimeError(
                     f'Failed to create singularity library directory {lib_path}'
-                )
+                ) from e
 
         if '://' in image:
             ctx, cname = image.split('://', 1)
             if ctx == 'file':
                 return image
-            else:
-                return os.path.join(
-                    lib_path,
-                    cname.replace('/', '-').replace(':', '-') + '.sif')
-        elif os.path.isfile(image):
+            return os.path.join(
+                lib_path,
+                cname.replace('/', '-').replace(':', '-') + '.sif')
+        if os.path.isfile(image):
             # if image is a filename, ok
             return image
-        else:
-            # otherwise assuming it is an image in SoS Singulariry Library
-            return os.path.join(lib_path, image)
+        # otherwise assuming it is an image in SoS Singulariry Library
+        return os.path.join(lib_path, image)
 
     def pull(self, image):
         self._ensure_singularity()
@@ -278,7 +276,7 @@ class SoS_SingularityClient:
                 f'HINT: Pulling singularity image {image} to {image_file.replace(os.path.expanduser("~"), "~")}'
             )
             subprocess.check_output(
-                'singularity pull {} {}'.format(image_file, image),
+                f"singularity pull {image_file} {image}",
                 stderr=subprocess.STDOUT,
                 shell=True,
                 universal_newlines=True)
@@ -290,8 +288,7 @@ class SoS_SingularityClient:
         if not path(image_file).exists():
             raise ValueError(
                 f'Image {image_file} does not exist after pulling {image}.')
-        else:
-            print(f'HINT: Singularity image {image} is now up to date')
+        print(f'HINT: Singularity image {image} is now up to date')
         send_message_to_controller(
             ['resource', 'singularity_image', 'available', image])
 
@@ -304,14 +301,14 @@ class SoS_SingularityClient:
             **kwargs):
         self._ensure_singularity()
         #
-        env.logger.debug('singularity_run with keyword args {}'.format(kwargs))
+        env.logger.debug(f"singularity_run with keyword args {kwargs}")
         #
         # now, write a temporary file to a tempoary directory under the current directory, this is because
         # we need to share the directory to ...
         with tempfile.TemporaryDirectory(dir=os.getcwd()) as tempdir:
             # keep the temporary script for debugging purposes
             # tempdir = tempfile.mkdtemp(dir=os.getcwd())
-            tempscript = 'singularity_run_{}{}'.format(os.getpid(), suffix)
+            tempscript = f"singularity_run_{os.getpid()}{suffix}"
             if script:
                 with open(os.path.join(tempdir, tempscript),
                           'w') as script_file:
@@ -324,12 +321,22 @@ class SoS_SingularityClient:
                 args = '{filename:pq}'
             #
             # under mac, we by default share /Users within Singularity
+            exec_opts = []
             if 'bind' in kwargs:
                 binds = [kwargs['bind']] if isinstance(kwargs['bind'],
                                                        str) else kwargs['bind']
-                bind_opt = ' '.join('-B {}'.format(x) for x in binds)
-            else:
-                bind_opt = ''
+                exec_opts.extend([f"-B {x}" for x in binds])
+                kwargs.pop('bind', None)
+
+            for opt in ['nv', 'disable_cache', 'nohttps', 'nonet', 'vm_err']:
+                if opt in kwargs and kwargs[opt]:
+                    exec_opts.append('--' + opt.replace('_', '-'))
+                    kwargs.pop(opt)
+
+            for opt in ['home', 'vm_cpu', 'vm_ip', 'vm_ram']:
+                if opt in kwargs:
+                    exec_opts.append('--' + opt.replace('_', '-') + ' ' + kwargs[opt])
+                    kwargs.pop(opt)
 
             cmd_opt = interpolate(
                 f'{interpreter if isinstance(interpreter, str) else interpreter[0]} {args}',
@@ -338,10 +345,8 @@ class SoS_SingularityClient:
                     'script': script
                 })
 
-            cmd = 'singularity exec {} {} {}'.format(
-                bind_opt,  # volumes
-                self._image_file(image),
-                cmd_opt)
+            cmd = f"singularity exec {' '.join(exec_opts)} {self._image_file(image)} {cmd_opt}"
+
             env.logger.debug(cmd)
             if env.config['run_mode'] == 'dryrun':
                 print(f'HINT: {cmd}')
@@ -351,11 +356,13 @@ class SoS_SingularityClient:
             ret = self._run_cmd(cmd, **kwargs)
 
             if ret != 0:
-                debug_script_dir = os.path.join(env.exec_dir, '.sos')
-                msg = 'The script has been saved to {}/{}. To reproduce the error please run:\n``{}``'.format(
-                    debug_script_dir, tempscript,
-                    cmd.replace(f'{path(tempdir):p}',
-                                f'{path(debug_script_dir):p}'))
+                debug_script_dir = env.exec_dir
+                cmd_line = cmd.replace(f'{path(tempdir):p}',
+                                f'{path(debug_script_dir):p}')
+                msg = (
+                    f"The script has been saved to {debug_script_dir}/{debug_script_dir}."
+                    f"To reproduce the error please run:\n``{cmd_line}``"
+                )
                 shutil.copy(os.path.join(tempdir, tempscript), debug_script_dir)
                 out = f", stdout={kwargs['stdout']}" if 'stdout' in kwargs and os.path.isfile(
                     kwargs['stdout']) and os.path.getsize(
