@@ -4,6 +4,7 @@
 # Distributed under the terms of the 3-clause BSD License.
 
 import contextlib
+import os
 import subprocess
 import sys
 from io import StringIO
@@ -11,21 +12,15 @@ from io import StringIO
 import zmq
 
 from .controller import close_socket, create_socket, send_message_to_controller
-from .messages import encode_msg
 from .eval import SoS_exec
-from .executor_utils import (
-    clear_output,
-    create_task,
-    get_traceback_msg,
-    kill_all_subprocesses,
-    prepare_env,
-    reevaluate_output,
-    statementMD5,
-    validate_step_sig,
-    verify_input,
-)
+from .executor_utils import (clear_output, create_task, get_traceback_msg,
+                             kill_all_subprocesses, prepare_env,
+                             reevaluate_output, statementMD5,
+                             validate_step_sig, verify_input)
+from .messages import encode_msg
 from .targets import RemovedTarget, RuntimeInfo, UnavailableLock, sos_targets
-from .utils import ArgumentError, StopInputGroup, TerminateExecution, ProcessKilled, env
+from .utils import (ArgumentError, ProcessKilled, StopInputGroup,
+                    TerminateExecution, env)
 
 
 @contextlib.contextmanager
@@ -50,6 +45,7 @@ def execute_substep(
     proc_vars={},
     shared_vars=[],
     config={},
+    cwd=None,
 ):
     """Execute a substep with specific input etc
 
@@ -104,10 +100,8 @@ def execute_substep(
     assert "result_push_socket" in config["sockets"]
 
     # this should not happen but check nevertheless
-    if (
-        env.result_socket_port is not None
-        and env.result_socket_port != config["sockets"]["result_push_socket"]
-    ):
+    if (env.result_socket_port is not None and
+            env.result_socket_port != config["sockets"]["result_push_socket"]):
         close_socket(env.result_socket)
         env.result_socket = None
 
@@ -126,13 +120,13 @@ def execute_substep(
         proc_vars=proc_vars,
         shared_vars=shared_vars,
         config=config,
+        cwd=cwd,
     )
     env.result_socket.send(encode_msg(res))
 
 
-def _execute_substep(
-    stmt, global_def, global_vars, task, task_params, proc_vars, shared_vars, config
-):
+def _execute_substep(stmt, global_def, global_vars, task, task_params,
+                     proc_vars, shared_vars, config, cwd):
     # vatlab/sos-notebook#272
     # if config contains exec_mode, we remove it to avoid it manifest the worker exec_mode
     config.pop("exec_mode", None)
@@ -142,7 +136,8 @@ def _execute_substep(
     prepare_env(global_def, global_vars)
     # update it with variables passed from master process
     env.sos_dict.quick_update(proc_vars)
-    if env.config["sig_mode"] == "ignore" or env.sos_dict["_output"].unspecified():
+    if env.config["sig_mode"] == "ignore" or env.sos_dict[
+            "_output"].unspecified():
         sig = None
     else:
         sig = RuntimeInfo(
@@ -157,7 +152,12 @@ def _execute_substep(
     errmsg = ""
     capture_output = env.config["run_mode"] == "interactive"
     idx = env.sos_dict["_index"]
+    original_cwd = None
     try:
+        if cwd:
+            original_cwd = os.getcwd()
+            if original_cwd != cwd:
+                os.chdir(cwd)
         if sig:
             # if not in distributed mode, the signature must have been checked at
             # the step level
@@ -167,9 +167,9 @@ def _execute_substep(
                     # avoid sig being released in the final statement
                     sig = None
                     # complete case: concurrent ignore without task
-                    send_message_to_controller(
-                        ["progress", "substep_ignored", env.sos_dict["step_id"]]
-                    )
+                    send_message_to_controller([
+                        "progress", "substep_ignored", env.sos_dict["step_id"]
+                    ])
                     res = {
                         "index": idx,
                         "ret_code": 0,
@@ -192,7 +192,6 @@ def _execute_substep(
         verify_input(ignore_internal_targets=True)
 
         if stmt:
-
             # statement can be empty for task only substep
             if capture_output:
                 with stdoutIO() as (out, err):
@@ -206,9 +205,8 @@ def _execute_substep(
                     f'``{env.sos_dict["step_name"]}`` (index={idx}) is ``completed``.'
                 )
         if task:
-            task_id, taskdef, task_vars = create_task(
-                global_def, global_vars, task, task_params
-            )
+            task_id, taskdef, task_vars = create_task(global_def, global_vars,
+                                                      task, task_params)
             res = {
                 "index": idx,
                 "task_id": task_id,
@@ -232,10 +230,10 @@ def _execute_substep(
                 res.update({"stdout": outmsg, "stderr": errmsg})
             # complete case: concurrent execution without task
             send_message_to_controller(
-                ["progress", "substep_completed", env.sos_dict["step_id"]]
-            )
+                ["progress", "substep_completed", env.sos_dict["step_id"]])
         return res
-    except (StopInputGroup, TerminateExecution, RemovedTarget, UnavailableLock) as e:
+    except (StopInputGroup, TerminateExecution, RemovedTarget,
+            UnavailableLock) as e:
         # stop_if is not considered as an error
         if isinstance(e, StopInputGroup):
             if e.message:
@@ -247,8 +245,8 @@ def _execute_substep(
             if task:
                 res["task_id"] = None
             if not e.keep_output:
-                # treat as an error
                 clear_output()
+                # treat as an error
                 res["output"] = sos_targets([])
             elif sig:
                 sig.set_output(env.sos_dict["_output"])
@@ -298,6 +296,8 @@ def _execute_substep(
             res.update({"stdout": outmsg, "stderr": errmsg})
         return res
     finally:
+        if original_cwd:
+            os.chdir(original_cwd)
         # release the lock even if the process becomes zombie? #871
         if sig:
             sig.release(quiet=True)
