@@ -5,7 +5,6 @@
 
 import keyword
 import re
-
 from typing import Callable, List
 
 SOS_TARGETS_OPTIONS = [
@@ -61,17 +60,13 @@ SOS_DIRECTIVES = ["input", "output", "depends", "task", "parameter"]
 SOS_SECTION_OPTIONS = ["provides", "shared", "workdir"]
 
 SOS_KEYWORDS = (
-    SOS_INPUT_OPTIONS
-    + SOS_OUTPUT_OPTIONS
-    + SOS_DEPENDS_OPTIONS
-    + SOS_RUNTIME_OPTIONS
-    + SOS_ACTION_OPTIONS
-    + SOS_DIRECTIVES
-    + SOS_SECTION_OPTIONS
-)
+    SOS_INPUT_OPTIONS + SOS_OUTPUT_OPTIONS + SOS_DEPENDS_OPTIONS +
+    SOS_RUNTIME_OPTIONS + SOS_ACTION_OPTIONS + SOS_DIRECTIVES +
+    SOS_SECTION_OPTIONS)
 
 SOS_USAGES = {
-    "input": """
+    "input":
+        """
 input: filename, filename, ... [group_by=GROUP] [filetype=FILETYPE]
           [paired_with=PAIRS] [for_each=VARS] [pattern=PATTEN]
 
@@ -79,14 +74,16 @@ Specify input targets of a SoS step.
 
 See online documentation for details of variables.
 """,
-    "output": """
+    "output":
+        """
 output: target, target, ...
 
 Specify output targets of a SoS step.
 
 See online documentation for details of variables.
 """,
-    "depends": """
+    "depends":
+        """
 depends: target, target, ...
 
 Specify dependent targets of a SoS step.
@@ -139,9 +136,8 @@ class LazyRegex(object):
 
     def _compile_and_collapse(self) -> None:
         """Actually compile the requested regex"""
-        self._real_regex = self._real_re_compile(
-            *self._regex_args, **self._regex_kwargs
-        )
+        self._real_regex = self._real_re_compile(*self._regex_args,
+                                                 **self._regex_kwargs)
         for attr in self._regex_attributes_to_copy:
             setattr(self, attr, getattr(self._real_regex, attr))
 
@@ -152,7 +148,7 @@ class LazyRegex(object):
         except re.error as e:
             # raise ValueError instead of re.error as this gives a
             # cleaner message to the user.
-            raise ValueError('"' + args[0] + '" ' + str(e))
+            raise ValueError('"' + args[0] + '" ' + str(e)) from e
 
     def __getstate__(self):
         """Return the state to use when pickling."""
@@ -228,16 +224,14 @@ _SUBWORKFLOW_TMPL = r"""
     \s*$                               # end
     """
 
-_SECTION_OPTION_TMPL = r"""
+_SECTION_OPTION_TMPL = rf"""
     ^\s*                               # start
-    (?P<name>{})                       # one of the option names
+    (?P<name>{'|'.join(SOS_SECTION_OPTIONS)})                       # one of the option names
     (\s*=\s*                           # =
     (?P<value>.+)                      # value
     )?                                 # value is optional
     \s*$
-    """.format(
-    "|".join(SOS_SECTION_OPTIONS)
-)
+    """
 
 _FORMAT_LINE_TMPL = r"""
     ^                                  # from first column
@@ -253,11 +247,11 @@ _FORMAT_VERSION_TMPL = r"""
     \s*$                               # till end of line
     """
 
-_DIRECTIVE_TMPL = r"""
+_DIRECTIVE_TMPL = rf"""
     ^                                  # from start of line
     (?P<directive_name>                #
-    (?!({})\s*:)                       # not a python keyword followed by : (can be input)
-    ({}                                # name of directive
+    (?!({"|".join(keyword.kwlist)})\s*:)                       # not a python keyword followed by : (can be input)
+    ({"|".join(SOS_DIRECTIVES)}                                # name of directive
     |[a-zA-Z][\w\d_]*))             #    or action
     \s*:\s*                            # followed by :
     (?P<directive_value>               # and values that can be
@@ -266,14 +260,12 @@ _DIRECTIVE_TMPL = r"""
                                        # a(), or arbitrary expression (['a'...], dictionary, set
                                        # etc) which is difficult to match, so we use negative
                                        # pattern to exclude expressions starting with :, | etc
-    """.format(
-    "|".join(keyword.kwlist), "|".join(SOS_DIRECTIVES)
-)
+    """
 
-_INDENTED_ACTION_TMPL = r"""
+_INDENTED_ACTION_TMPL = rf"""
     ^                                  # from start of line but allow space
     (?P<action_name>                   #
-    (?!\s+({}|{})\s*:)                 # not a python keyword or SoS directive followed by :
+    (?!\s+({"|".join(keyword.kwlist)}|{"|".join(SOS_DIRECTIVES)})\s*:)                 # not a python keyword or SoS directive followed by :
     (\s+[a-zA-Z][\w\d_]*))             #    or action
     \s*:\s*                            # followed by :
     (?P<action_value>                  # and values that can be
@@ -282,9 +274,7 @@ _INDENTED_ACTION_TMPL = r"""
                                        # a(), or arbitrary expression (['a'...], dictionary, set
                                        # etc) which is difficult to match, so we use negative
                                        # pattern to exclude expressions starting with :, | etc
-    """.format(
-    "|".join(keyword.kwlist), "|".join(SOS_DIRECTIVES)
-)
+    """
 
 _ASSIGNMENT_TMPL = r"""
     ^                                  # from start of line
