@@ -4,11 +4,11 @@
 # Distributed under the terms of the 3-clause BSD License.
 
 import os
-
-from sos.targets import BaseTarget, textMD5
-from sos.utils import env
 import shutil
 
+from sos.targets import BaseTarget
+from sos.utils import env, textMD5
+
 
 class R_library(BaseTarget):
     """A target for a R library."""
@@ -22,7 +22,7 @@ class R_library(BaseTarget):
         repos="http://cran.us.r-project.org",
         autoinstall=False,
     ):
-        super(R_library, self).__init__()
+        super().__init__()
         self._library = library
         if version is not None:
             version = (version,) if isinstance(version, str) else tuple(version)
@@ -36,16 +36,15 @@ class R_library(BaseTarget):
         Therefore if the input name is {repo}/{pkg} the package will be
         installed from github if not available, else from cran or bioc
         """
-        from sos.pattern import glob_wildcards
-        import tempfile
         import subprocess
+        import tempfile
+
+        from sos.pattern import glob_wildcards
 
         output_file = tempfile.NamedTemporaryFile(
-            mode="w+t", suffix=".txt", delete=False
-        ).name
+            mode="w+t", suffix=".txt", delete=False).name
         script_file = tempfile.NamedTemporaryFile(
-            mode="w+t", suffix=".R", delete=False
-        ).name
+            mode="w+t", suffix=".R", delete=False).name
         #
         package_loaded = (
             "suppressMessages(require(package, character.only=TRUE, quietly=TRUE))"
@@ -92,11 +91,12 @@ class R_library(BaseTarget):
             # check version and mark version mismatch
             # if current version satisfies any of the
             # requirement the check program quits
-            version_satisfied = "||".join(
-                [f"(cur_version {y} {repr(x)})" for x, y in zip(version, operators)]
-            )
+            version_satisfied = "||".join([
+                f"(cur_version {y} {repr(x)})"
+                for x, y in zip(version, operators)
+            ])
         #
-        if len(glob_wildcards("{repo}@{pkg}", [name])["repo"]):
+        if len(glob_wildcards("{repo}@{pkg}", [name])["repo"]) > 0:
             # package is from github
             self._install("remotes>=2.0.0", None, repos)
             install_script = f"""
@@ -153,10 +153,12 @@ class R_library(BaseTarget):
             with open(script_file, "w") as sfile:
                 sfile.write(install_script)
             #
-            p = subprocess.Popen(["Rscript", "--default-packages=utils", script_file])
+            p = subprocess.Popen(
+                ["Rscript", "--default-packages=utils", script_file])
             ret = p.wait()
             if ret != 0:
-                env.logger.warning(f"Failed to detect or install R library {name}")
+                env.logger.warning(
+                    f"Failed to detect or install R library {name}")
                 return False
         except Exception as e:
             env.logger.error(f"Failed to execute script: {e}")
@@ -175,12 +177,12 @@ class R_library(BaseTarget):
                 elif status.strip() == "UNAVAILABLE":
                     env.logger.error(f"R library {lib} is not available.")
                 elif status.strip() == "AVAILABLE":
-                    env.logger.debug(f"R library {lib} ({cur_version}) is available")
+                    env.logger.debug(
+                        f"R library {lib} ({cur_version}) is available")
                     ret_val = True
                 elif status.strip() == "INSTALLED":
                     env.logger.debug(
-                        f"R library {lib} ({cur_version}) has been installed"
-                    )
+                        f"R library {lib} ({cur_version}) has been installed")
                     ret_val = True
                 elif status.strip() == "VERSION_MISMATCH":
                     env.logger.error(
@@ -195,22 +197,20 @@ class R_library(BaseTarget):
         return ret_val
 
     def target_exists(self, mode="any"):
-        if (self._library, self._version, self._autoinstall) in self.LIB_STATUS_CACHE:
-            return self.LIB_STATUS_CACHE[
-                (self._library, self._version, self._autoinstall)
-            ]
-        else:
-            # check if R is installed
-            if not shutil.which("Rscript"):
-                env.logger.debug(
-                    f'Target R_Library("{self._library}") does not exist because command Rscript is not found.'
-                )
-                return False
-            ret = self._install(self._library, self._version, self._repos)
-            self.LIB_STATUS_CACHE[
-                (self._library, self._version, self._autoinstall)
-            ] = ret
-            return ret
+        if (self._library, self._version,
+                self._autoinstall) in self.LIB_STATUS_CACHE:
+            return self.LIB_STATUS_CACHE[(self._library, self._version,
+                                          self._autoinstall)]
+        # check if R is installed
+        if not shutil.which("Rscript"):
+            env.logger.debug(
+                f'Target R_Library("{self._library}") does not exist because command Rscript is not found.'
+            )
+            return False
+        ret = self._install(self._library, self._version, self._repos)
+        self.LIB_STATUS_CACHE[(self._library, self._version,
+                                self._autoinstall)] = ret
+        return ret
 
     def target_name(self):
         return self._library
@@ -220,8 +220,8 @@ class R_library(BaseTarget):
             return (
                 f'{self.__class__.__name__}("{self.target_name()}", {self._version!r})'
             )
-        else:
-            return super(R_library, self).__repr__()
+        return super().__repr__()
+
 
     def target_signature(self, mode="any"):
         # we are supposed to get signature of the library, but we cannot
