@@ -11,10 +11,10 @@ import time
 from collections import OrderedDict, defaultdict
 
 from .eval import cfg_interpolate
-from .utils import env, expand_time
-from .tasks import TaskFile
 from .messages import encode_msg
 from .targets import sos_targets
+from .tasks import TaskFile
+from .utils import env, expand_time
 
 
 class TaskEngine(threading.Thread):
@@ -160,6 +160,8 @@ class TaskEngine(threading.Thread):
                 try:
                     # return creation time, start time, and duration
                     tid, tags, ct, st, dr, tst = line.split('\t')
+                    if tid.startswith('w'):
+                        continue
                     # for some reason on windows there can be a \r at the end
                     self.task_status[tid] = tst.strip()
                     self.task_info[tid]['date'] = [
@@ -188,12 +190,11 @@ class TaskEngine(threading.Thread):
                         verbosity=3,
                         numeric_times=True)
                     continue
-                elif self._status_checker.running():
+                if self._status_checker.running():
                     time.sleep(0.01)
                     continue
-                else:
-                    status_output = self._status_checker.result()
-                    self._status_checker = None
+                status_output = self._status_checker.result()
+                self._status_checker = None
                 #
                 for line in status_output.splitlines():
                     if not line.strip():
@@ -320,14 +321,13 @@ class TaskEngine(threading.Thread):
                             # env.logger.info(f'{tid} ``runnng``')
                             removed_from_pending.add(tid)
                             continue
-                        elif tid in self.canceled_tasks:
+                        if tid in self.canceled_tasks:
                             # the job is canceled while being prepared to run
                             removed_from_pending.add(tid)
                             # env.logger.info(f'{tid} ``canceled``')
                             continue
-                        else:
-                            slot.append(tid)
-                            n_submitted += 1
+                        slot.append(tid)
+                        n_submitted += 1
 
                         if len(slot) == self.batch_size or idx == len(self.pending_tasks) - 1 \
                             or n_submitted >= self.max_running_jobs - num_active_tasks:
@@ -369,7 +369,7 @@ class TaskEngine(threading.Thread):
                     self.last_report = time.time()
                     env.log_to_file(
                         'TASK',
-                        f'No running or pending task. Task engine is idle.')
+                        'No running or pending task. Task engine is idle.')
 
     def submit_task(self, task_id):
         # we wait for the engine to start
@@ -410,7 +410,7 @@ class TaskEngine(threading.Thread):
                 # because we do not know if the user asks to rerun (-s force), we have to
                 # resubmit the job. In the case of not-rerun, the task would be marked
                 # completed very soon.
-                elif self.task_status[task_id] == 'completed':
+                if self.task_status[task_id] == 'completed':
                     if task_id in self.running_pending_tasks:
                         self.running_pending_tasks.pop(task_id)
                     if task_id in env.config.get('resumed_tasks', []):
@@ -421,8 +421,7 @@ class TaskEngine(threading.Thread):
                         # self.notify_controller(['new-status', task_id, 'completed'])
                         env.logger.info(f'{task_id} ``resume with completed``')
                         return 'completed'
-                    else:
-                        env.logger.info(f'{task_id} ``re-execute completed``')
+                    env.logger.info(f'{task_id} ``re-execute completed``')
                 elif self.task_status[task_id] != 'new':
                     env.logger.info(
                         f'{task_id} ``restart`` from status ``{self.task_status[task_id]}``'
@@ -536,7 +535,7 @@ class TaskEngine(threading.Thread):
                 elif task_id in self.running_tasks:
                     # this should not happen
                     env.logger.warning(
-                        f'Task in "new" status when it is supposed to be running. Resubmitting.'
+                        'Task in "new" status when it is supposed to be running. Resubmitting.'
                     )
                     self.submit_task(task_id)
                 if task_id in self.pending_tasks:
@@ -558,8 +557,7 @@ class TaskEngine(threading.Thread):
                     self.running_pending_tasks.pop(task_id)
                 # status changed to completed
                 self.task_results[task_id] = self._thread_workers.submit(
-                    self.agent.receive_result,
-                    task_id)
+                    self.agent.receive_result, task_id)
             # for running pending tasks
             if status == 'aborted' and task_id in self.running_pending_tasks:
                 self.pending_tasks.append(task_id)
@@ -577,21 +575,28 @@ class TaskEngine(threading.Thread):
                         else:
                             res[task_id] = self.task_results[task_id].result()
                     elif task_id in self.task_status:
-                        if self.task_status[task_id] in ('running', 'pending', 'submitted'):
+                        if self.task_status[task_id] in ('running', 'pending',
+                                                         'submitted'):
                             time.sleep(0.1)
                         else:
                             res[task_id] = {
-                                'task': task_id,
-                                'exception': ValueError(f'Task {task_id} returns status {self.task_status[task_id]}'),
-                                'ret_code': 1,
-                                'output': sos_targets()
+                                'task':
+                                    task_id,
+                                'exception':
+                                    ValueError(
+                                        f'Task {task_id} returns status {self.task_status[task_id]}'
+                                    ),
+                                'ret_code':
+                                    1,
+                                'output':
+                                    sos_targets()
                             }
                     else:
                         res[task_id] = {
-                                'task': task_id,
-                                'exception': ValueError(f'Missing task {task_id}'),
-                                'ret_code': 1,
-                                'output': sos_targets()
+                            'task': task_id,
+                            'exception': ValueError(f'Missing task {task_id}'),
+                            'ret_code': 1,
+                            'output': sos_targets()
                         }
             if len(res) == len(task_ids):
                 return res
@@ -606,11 +611,13 @@ class TaskEngine(threading.Thread):
                     tags=None,
                     status=None):
         try:
+            # pylint: disable=consider-using-f-string
             return self.agent.check_output(
-                "{} status {} -v {} {} {} {} {} {}".format(
+                "{} status {} -v {} {} {} {} {} {} {}".format(
                     self.agent.config.get('sos', 'sos'),
                     '' if tasks is None else ' '.join(tasks),
                     verbosity,
+                    '--all tasks' if check_all else '',
                     '--html' if html else '',
                     '--numeric-times' if numeric_times else '',
                     f'--age {age}' if age else '',
@@ -656,17 +663,18 @@ class TaskEngine(threading.Thread):
         #
         # verbosity cannot be send to underlying command because task engines
         # rely on the output of certain verbosity (-v1) to post kill the jobs
+        # pylint: disable=consider-using-f-string
         cmd = "{} kill {} {} {}".format(
             self.agent.config.get('sos',
                                   'sos'), '' if all_tasks else ' '.join(tasks),
             f'--tags {" ".join(tags)}' if tags else '',
-            '-a' if all_tasks else '')
+            '--all tasks' if all_tasks else '')
 
         try:
             ret = self.agent.check_output(cmd)
             env.logger.debug(f'"{cmd}" executed with response "{ret}"')
         except subprocess.CalledProcessError:
-            env.logger.error(f'Failed to kill all tasks' if all_tasks else
+            env.logger.error('Failed to kill all tasks' if all_tasks else
                              f'Failed to kill tasks {" ".join(tasks)}')
             return ''
         return ret
@@ -698,6 +706,7 @@ class TaskEngine(threading.Thread):
             #                 os.path.expanduser('~'), '.sos', 'tasks', x +
             #                 '.task'))
             #     ]
+            # pylint: disable=consider-using-f-string
             return self.agent.check_output(
                 "{} purge {} {} {} {} {} -v {}".format(
                     self.agent.config.get('sos', 'sos'), ' '.join(tasks),
@@ -714,7 +723,7 @@ class TaskEngine(threading.Thread):
 class BackgroundProcess_TaskEngine(TaskEngine):
 
     def __init__(self, agent):
-        super(BackgroundProcess_TaskEngine, self).__init__(agent)
+        super().__init__(agent)
         self.wait_for_task = False
         if 'task_template' in self.config:
             self.task_template = self.config['task_template'].replace(
@@ -735,8 +744,7 @@ class BackgroundProcess_TaskEngine(TaskEngine):
             self.batch_size = 1000
 
     def execute_tasks(self, task_ids):
-        if not super(BackgroundProcess_TaskEngine,
-                     self).execute_tasks(task_ids):
+        if not super().execute_tasks(task_ids):
             env.log_to_file('TASK', f'Failed to prepare task {task_ids}')
             return False
         if self.task_template:
@@ -790,7 +798,7 @@ class BackgroundProcess_TaskEngine(TaskEngine):
                 job_text += '\n'
             except Exception as e:
                 raise ValueError(
-                    f'Failed to generate job file for task {task_id}: {e}')
+                    f'Failed to generate job file for task {task_id}: {e}') from e
 
         filename = task_ids[0] + ('.sh' if len(task_ids) == 1 else
                                   f'-{task_ids[-1]}.sh')
@@ -810,5 +818,5 @@ class BackgroundProcess_TaskEngine(TaskEngine):
             env.log_to_file('TASK', f'Execute "{cmd}" with script {job_text}')
             self.agent.run_command(cmd, wait_for_task=self.wait_for_task)
         except Exception as e:
-            raise RuntimeError(f'Failed to submit task {task_ids}: {e}')
+            raise RuntimeError(f'Failed to submit task {task_ids}: {e}') from e
         return True
