@@ -5,28 +5,19 @@
 
 import multiprocessing as mp
 import os
+import pickle
 import signal
 import time
-import pickle
 from typing import Any, Dict, Optional
 
 import zmq
 
-from .controller import (
-    close_socket,
-    connect_controllers,
-    create_socket,
-    disconnect_controllers,
-)
+from .controller import (close_socket, connect_controllers, create_socket,
+                         disconnect_controllers)
 from .executor_utils import kill_all_subprocesses, prepare_env
-from .utils import (
-    env,
-    ProcessKilled,
-    short_repr,
-    get_localhost_ip,
-    get_open_files_and_connections,
-)
-from .messages import encode_msg, decode_msg
+from .messages import decode_msg, encode_msg
+from .utils import (ProcessKilled, env, get_localhost_ip,
+                    get_open_files_and_connections, short_repr)
 
 
 def signal_handler(*args, **kwargs):
@@ -109,7 +100,9 @@ class SoS_Worker(mp.Process):
 
     """
 
-    def __init__(self, config: Optional[Dict[str, Any]] = None, **kwargs) -> None:
+    def __init__(self,
+                 config: Optional[Dict[str, Any]] = None,
+                 **kwargs) -> None:
         """
 
         config:
@@ -124,7 +117,7 @@ class SoS_Worker(mp.Process):
             immediately available.
         """
         # the worker process knows configuration file, command line argument etc
-        super(SoS_Worker, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         #
         self.config = config
         self.local_ip = get_localhost_ip()
@@ -140,25 +133,26 @@ class SoS_Worker(mp.Process):
     def waiting_runners(self):
         # check if
         return [
-            idx
-            for idx, runner in enumerate(self._runners)
+            idx for idx, runner in enumerate(self._runners)
             if isinstance(runner, Runner) and runner.can_proceed()
         ]
 
     def completed_runners(self):
-        return [idx for idx, runner in enumerate(self._runners) if runner is True]
+        return [
+            idx for idx, runner in enumerate(self._runners) if runner is True
+        ]
 
     def available_ports(self):
         # when a runner is completed, its port becomes available and can
         # be used to accept more jobs.
         return [
-            port
-            for port, runner in zip(self._master_ports, self._runners)
+            port for port, runner in zip(self._master_ports, self._runners)
             if runner is True
         ]
 
     def num_pending(self):
-        return len([runner for runner in self._runners if isinstance(runner, Runner)])
+        return len(
+            [runner for runner in self._runners if isinstance(runner, Runner)])
 
     def switch_to(self, idx):
         if len(self._master_sockets) > idx:
@@ -169,34 +163,32 @@ class SoS_Worker(mp.Process):
             assert idx == len(self._master_ports)
             # a new socket is needed
             env.master_socket = create_socket(env.zmq_context, zmq.PAIR)
-            port = env.master_socket.bind_to_random_port(f"tcp://{self.local_ip}")
+            port = env.master_socket.bind_to_random_port(
+                f"tcp://{self.local_ip}")
             # switch to a new env_idx and returns new_idx, old_idx
             self._env_idx.append(env.request_new()[0])
             self._master_sockets.append(env.master_socket)
             self._master_ports.append(f"tcp://{self.local_ip}:{port}")
             self._runners.append(True)
-            if "WORKER" in env.config["SOS_DEBUG"] or "ALL" in env.config["SOS_DEBUG"]:
+            if "WORKER" in env.config["SOS_DEBUG"] or "ALL" in env.config[
+                    "SOS_DEBUG"]:
                 env.log_to_file(
                     "WORKER",
                     f"WORKER {self.name} ({os.getpid()}) creates ports {self._master_ports}",
                 )
 
     def __repr__(self):
-        return (
-            self.name
-            + " "
-            + " ".join(
-                str(x) if isinstance(x, Runner) else str(idx)
-                for idx, x in enumerate(self._runners)
-            )
-        )
+        return (self.name + " " + " ".join(
+            str(x) if isinstance(x, Runner) else str(idx)
+            for idx, x in enumerate(self._runners)))
 
     def run(self):
         # env.logger.warning(f'Worker created {os.getpid()}')
         env.config.update(self.config)
         env.verbosity = self.config.get("verbosity", 2)
 
-        if "PROFILE" in env.config["SOS_DEBUG"] or "ALL" in env.config["SOS_DEBUG"]:
+        if "PROFILE" in env.config["SOS_DEBUG"] or "ALL" in env.config[
+                "SOS_DEBUG"]:
             import cProfile
 
             pr = cProfile.Profile()
@@ -205,7 +197,8 @@ class SoS_Worker(mp.Process):
         env.zmq_context = connect_controllers()
 
         # create controller socket
-        env.ctrl_socket = create_socket(env.zmq_context, zmq.REQ, "worker backend")
+        env.ctrl_socket = create_socket(env.zmq_context, zmq.REQ,
+                                        "worker backend")
         # worker_backend, or the router, might be on another machine
         env.log_to_file(
             "WORKER",
@@ -221,10 +214,8 @@ class SoS_Worker(mp.Process):
         # wait to handle jobs
         while True:
             try:
-                if (
-                    "OPENFILES" in env.config["SOS_DEBUG"]
-                    or "ALL" in env.config["SOS_DEBUG"]
-                ):
+                if ("OPENFILES" in env.config["SOS_DEBUG"] or
+                        "ALL" in env.config["SOS_DEBUG"]):
                     ofc = get_open_files_and_connections(os.getpid())
                     env.log_to_file(
                         "OPENFILES",
@@ -235,7 +226,8 @@ class SoS_Worker(mp.Process):
                     for idx in wr:
                         self.switch_to(idx)
                         # it can be True for completion and Runner itself for continue
-                        self._runners[idx] = self._runners[idx].run_until_waiting()
+                        self._runners[idx] = self._runners[
+                            idx].run_until_waiting()
                     continue
 
                 cr = self.completed_runners()
@@ -249,19 +241,16 @@ class SoS_Worker(mp.Process):
                 # controller know if we have any pending job, and the controller might decide
                 # to kill this worker.
                 env.ctrl_socket.send(
-                    encode_msg([self.num_pending()] + self.available_ports())
-                )
+                    encode_msg([self.num_pending()] + self.available_ports()))
                 reply = decode_msg(env.ctrl_socket.recv())
 
                 if reply is None:
                     if len(wr) != 0:
                         env.logger.error(
-                            f"WORKER terminates with pending tasks. sos might not be termianting properly."
+                            "WORKER terminates with pending tasks. sos might not be termianting properly."
                         )
-                    if (
-                        "WORKER" in env.config["SOS_DEBUG"]
-                        or "ALL" in env.config["SOS_DEBUG"]
-                    ):
+                    if ("WORKER" in env.config["SOS_DEBUG"] or
+                            "ALL" in env.config["SOS_DEBUG"]):
                         env.log_to_file(
                             "WORKER",
                             f"WORKER {self.name} ({os.getpid()}) quits after receiving None.",
@@ -287,7 +276,7 @@ class SoS_Worker(mp.Process):
                     )
                     self._runners[new_idx] = True
                     continue
-                elif "task_id" in reply:
+                if "task_id" in reply:
                     self.run_task(reply)
                     env.log_to_file(
                         "WORKER",
@@ -304,17 +293,14 @@ class SoS_Worker(mp.Process):
                 # step and workflow can yield. Here we call run_until_waiting directly because we know the Runner can proceed.
                 self._runners[new_idx] = Runner(
                     self.run_step(**reply)
-                    if "section" in reply
-                    else self.run_workflow(**reply),
+                    if "section" in reply else self.run_workflow(**reply),
                     name=self._name_of_work(reply),
                 ).run_until_waiting()
-                if (
-                    "WORKER" in env.config["SOS_DEBUG"]
-                    or "ALL" in env.config["SOS_DEBUG"]
-                ):
+                if ("WORKER" in env.config["SOS_DEBUG"] or
+                        "ALL" in env.config["SOS_DEBUG"]):
                     env.log_to_file(
-                        "WORKER", "STATUS " + self._name_of_work(reply) + str(self)
-                    )
+                        "WORKER",
+                        "STATUS " + self._name_of_work(reply) + str(self))
             except ProcessKilled:
                 # in theory, this will not be executed because the exception
                 # will be caught by the step executor, and then sent to the master
@@ -323,8 +309,8 @@ class SoS_Worker(mp.Process):
             except KeyboardInterrupt:
                 # ignore SIGINT because workers are supposed to be killed through messages
                 env.log_to_file(
-                    "PROCESS", f"KeyboardInterrupt received by {os.getpid()}. Ignoring."
-                )
+                    "PROCESS",
+                    f"KeyboardInterrupt received by {os.getpid()}. Ignoring.")
         # Finished
         signal.signal(signal.SIGTERM, signal.SIG_DFL)
         kill_all_subprocesses(os.getpid())
@@ -335,11 +321,12 @@ class SoS_Worker(mp.Process):
             close_socket(socket, "worker master", now=True)
         close_socket(env.ctrl_socket, now=True)
         disconnect_controllers(env.zmq_context)
-        if "PROFILE" in env.config["SOS_DEBUG"] or "ALL" in env.config["SOS_DEBUG"]:
+        if "PROFILE" in env.config["SOS_DEBUG"] or "ALL" in env.config[
+                "SOS_DEBUG"]:
             pr.disable()
             pr_file = os.path.join(
-                os.path.expanduser("~"), ".sos", f"profile_worker_{os.getpid()}.txt"
-            )
+                os.path.expanduser("~"), ".sos",
+                f"profile_worker_{os.getpid()}.txt")
             pr.dump_stats(pr_file)
             print(
                 f"Execution profile of worker process {os.getpid()} is saved to {pr_file}"
@@ -348,24 +335,23 @@ class SoS_Worker(mp.Process):
     def _type_of_work(self, work):
         if "section" in work:
             return "step"
-        elif "wf" in work:
+        if "wf" in work:
             return "workflow"
-        elif "task_id" in work:
+        if "task_id" in work:
             return "task"
-        else:
-            return "substep"
+        return "substep"
 
     def _name_of_work(self, work):
         if "section" in work:
             return work["section"].step_name()
-        elif "wf" in work:
+        if "wf" in work:
             return work["workflow_id"]
-        elif "task_id" in work:
+        if "task_id" in work:
             return work["task_id"]
-        else:
-            return "substep"
+        return "substep"
 
-    def run_workflow(self, workflow_id, wf, targets, args, shared, config, **kwargs):
+    def run_workflow(self, workflow_id, wf, targets, args, shared, config,
+                     **kwargs):
         #
         #
         # get workflow, args, shared, and config
@@ -414,10 +400,7 @@ class SoS_Worker(mp.Process):
         # Execute global namespace. The reason why this is executed outside of
         # step is that the content of the dictioary might be overridden by context
         # variables.
-        prepare_env(
-            section.global_def, section.global_vars, env.config["workflow_vars"]
-        )
-
+        prepare_env(section.global_def, section.global_vars, env.config["workflow_vars"])
         # clear existing keys, otherwise the results from some random result
         # might mess with the execution of another step that does not define input
         for k in ["__step_input__", "__default_output__", "__step_output__"]:
@@ -430,8 +413,7 @@ class SoS_Worker(mp.Process):
         # __step_output__ from auxiliary steps. #526
         env.sos_dict.quick_update(context)
         executor = Step_Executor(
-            section, env.master_socket, mode=env.config["run_mode"]
-        )
+            section, env.master_socket, mode=env.config["run_mode"])
 
         runner = executor.run()
         try:
@@ -454,10 +436,8 @@ class SoS_Worker(mp.Process):
 
         result_socket = work["config"]["sockets"]["result_push_socket"]
 
-        if (
-            env.result_socket_port is not None
-            and env.result_socket_port != result_socket
-        ):
+        if (env.result_socket_port is not None and
+                env.result_socket_port != result_socket):
             close_socket(env.result_socket)
             env.result_socket = None
 
@@ -506,13 +486,14 @@ class WorkerManager(object):
                     self._worker_hosts.append(worker_proc)
                     # here we assume that all nodes have the same number of cores so that we use
                     # the default value for master node for all computing nodes
-                    self._max_workers.append(min(max(os.cpu_count() // 2, 2), 8))
+                    self._max_workers.append(
+                        min(max(os.cpu_count() // 2, 2), 8))
 
             self._num_workers = [0 for x in self._worker_procs]
-        except Exception:
+        except Exception as e:
             raise RuntimeError(
                 f"Incorrect format for option -j ({self._worker_procs}), which should be one or more [host:]nproc"
-            )
+            ) from e
 
         self._local_workers = []
         self._remote_connections = []
@@ -544,7 +525,8 @@ class WorkerManager(object):
         self.start_worker()
 
     def report(self, msg):
-        if "WORKER" in env.config["SOS_DEBUG"] or "ALL" in env.config["SOS_DEBUG"]:
+        if "WORKER" in env.config["SOS_DEBUG"] or "ALL" in env.config[
+                "SOS_DEBUG"]:
             env.log_to_file(
                 "WORKER",
                 f"{msg.upper()}: {self._num_workers} workers (of which {len(self._blocking_ports)} is blocking), {self._n_requested} requested, {self._n_processed} processed",
@@ -554,10 +536,10 @@ class WorkerManager(object):
         self._n_requested += 1
         if msg_type == "substep":
             self._substep_requests.insert(0, msg)
-            self.report(f"Substep requested")
+            self.report("Substep requested")
         elif msg_type == "task":
             self._task_requests.insert(0, msg)
-            self.report(f"Task requested")
+            self.report("Task requested")
         else:
             port = msg["config"]["sockets"]["master_port"]
             self._step_requests[port] = msg
@@ -606,7 +588,8 @@ class WorkerManager(object):
         if any(port in self._step_requests for port in ports):
             # if the port is available
             port = [x for x in ports if x in self._step_requests][0]
-            self._worker_backend_socket.send(encode_msg(self._step_requests.pop(port)))
+            self._worker_backend_socket.send(
+                encode_msg(self._step_requests.pop(port)))
             self._n_processed += 1
             self.report(f"Step {port} processed")
             # port should be in claimed ports
@@ -676,18 +659,17 @@ class WorkerManager(object):
             self._worker_backend_socket.send(encode_msg({}))
             ports = tuple(ports)
             if (
-                ports,
-                num_pending,
-            ) not in self._last_pending_msg or time.time() - self._last_pending_msg[
-                (ports, num_pending)
-            ] > 1.0:
-                self.report(f"pending with port {ports} at num_pending {num_pending}")
+                    ports,
+                    num_pending,
+            ) not in self._last_pending_msg or time.time(
+            ) - self._last_pending_msg[(ports, num_pending)] > 1.0:
+                self.report(
+                    f"pending with port {ports} at num_pending {num_pending}")
                 self._last_pending_msg[(ports, num_pending)] = time.time()
 
     def start_worker(self):
         for idx, (worker_host, num_worker, max_worker) in enumerate(
-            zip(self._worker_hosts, self._num_workers, self._max_workers)
-        ):
+                zip(self._worker_hosts, self._num_workers, self._max_workers)):
             if num_worker == max_worker:
                 continue
             # local host
@@ -705,8 +687,8 @@ class WorkerManager(object):
 
                     host = Host(worker_host, start_engine=False)
                     env_file = os.path.join(
-                        os.path.expanduser("~"), ".sos", f"worker_envs.{os.getpid()}"
-                    )
+                        os.path.expanduser("~"), ".sos",
+                        f"worker_envs.{os.getpid()}")
                     if not os.path.isfile(env_file):
                         with open(env_file, "wb") as envfile:
                             pickle.dump(
@@ -740,13 +722,12 @@ class WorkerManager(object):
                     self._remote_connections.append(p)
                 except Exception as e:
                     env.logger.error(
-                        f"Failed to start workers on host {worker_host}: {e}"
-                    )
+                        f"Failed to start workers on host {worker_host}: {e}")
                     raise RuntimeError(
-                        f"Failed to start workers on host {worker_host}: {e}"
-                    )
+                        f"Failed to start workers on host {worker_host}: {e}") from e
                 self._num_workers[idx] = self._max_workers[idx]
-                self.report(f"start {max_worker} remote workers on {worker_host}")
+                self.report(
+                    f"start {max_worker} remote workers on {worker_host}")
             break
 
     def check_workers(self):
@@ -756,7 +737,9 @@ class WorkerManager(object):
             self._local_worker_alive_time = time.time()
             # join processes if they are now gone, it should not do anything bad
             # if the process is still running
-            [worker.join() for worker in self._local_workers if not worker.is_alive()]
+            for worker in self._local_workers:
+                if not worker.is_alive():
+                    worker.join()
             self._local_workers = [
                 worker for worker in self._local_workers if worker.is_alive()
             ]
@@ -772,4 +755,6 @@ class WorkerManager(object):
             total_num_workers -= 1
             self.report(f"Kill {msg[1:]}")
         # join all local processes
-        [worker.join() for worker in self._local_workers]
+        for worker in self._local_workers:
+            worker.join()
+            
\ No newline at end of file
