@@ -3,24 +3,24 @@
 # Copyright (c) Bo Peng and the University of Texas MD Anderson Cancer Center
 # Distributed under the terms of the 3-clause BSD License.
 
+import base64
 import getpass
 import os
 import time
-import base64
 from collections import defaultdict
 
-from .utils import env, format_duration, dot_to_gif
-from .controller import request_answer_from_controller
 from ._version import __version__
+from .controller import request_answer_from_controller
+from .utils import dot_to_gif, env, format_duration
 
 
 class WorkflowSig(object):
+
     def __init__(self, workflow_id):
         self.data = defaultdict(lambda: defaultdict(list))
 
         for entry_type, id, item in request_answer_from_controller(
-            ["workflow_sig", "records", workflow_id]
-        ):
+            ["workflow_sig", "records", workflow_id]):
             try:
                 self.data[entry_type][id].append(item.strip())
             except Exception as e:
@@ -28,9 +28,8 @@ class WorkflowSig(object):
 
     def convert_time(self, info):
         for key in [x for x in info.keys() if x.endswith("_time")]:
-            info[key + "_str"] = time.strftime(
-                "%Y-%m-%d %H:%M:%S", time.localtime(info[key])
-            )
+            info[key + "_str"] = time.strftime("%Y-%m-%d %H:%M:%S",
+                                               time.localtime(info[key]))
         if "start_time" in info and "end_time" in info:
             info["duration"] = int(info["end_time"] - info["start_time"])
             info["duration_str"] = format_duration(info["duration"])
@@ -50,11 +49,11 @@ class WorkflowSig(object):
                 self.convert_time(v)
                 if "dag" in v:
                     try:
-                        v["dag_img"] = dot_to_gif(v["dag"], warn=env.logger.warning)
+                        v["dag_img"] = dot_to_gif(
+                            v["dag"], warn=env.logger.warning)
                     except Exception as e:
                         env.logger.warning(
-                            f"Failed to obtain convert dag to image: {e}"
-                        )
+                            f"Failed to obtain convert dag to image: {e}")
                 if "script" in v:
                     v["script"] = base64.b64decode(v["script"]).decode()
             return workflows
@@ -63,6 +62,7 @@ class WorkflowSig(object):
             return {}
 
     def tasks(self):
+
         def merge_dict(items):
             ret = {}
             for item in items:
@@ -71,7 +71,9 @@ class WorkflowSig(object):
 
         try:
             # there can be multiple task status for each id
-            tasks = {id: merge_dict(res) for id, res in self.data["task"].items()}
+            tasks = {
+                id: merge_dict(res) for id, res in self.data["task"].items()
+            }
             for val in tasks.values():
                 self.convert_time(val)
                 if "peak_cpu" in val:
@@ -85,8 +87,8 @@ class WorkflowSig(object):
     def steps(self):
         try:
             return {
-                wf: [self.convert_time(eval(x)) for x in steps]
-                for wf, steps in self.data["step"].items()
+                wf: [self.convert_time(eval(x)) for x in steps
+                    ] for wf, steps in self.data["step"].items()
             }
         except Exception as e:
             env.logger.warning(str(e))
@@ -95,8 +97,8 @@ class WorkflowSig(object):
     def transcripts(self):
         try:
             return {
-                step: [self.convert_time(eval(x)) for x in items]
-                for step, items in self.data["transcript"].items()
+                step: [self.convert_time(eval(x)) for x in items
+                      ] for step, items in self.data["transcript"].items()
             }
         except Exception as e:
             env.logger.warning(str(e))
@@ -116,10 +118,11 @@ def calc_timeline(info, start_time, total_duration):
         info["after_precent"] = 0
         return
     info["before_percent"] = int(
-        (info["start_time"] - start_time) * 100 / total_duration
-    )
-    info["during_percent"] = max(1, int(info["duration"] * 100 / total_duration))
-    info["after_percent"] = 100 - info["before_percent"] - info["during_percent"]
+        (info["start_time"] - start_time) * 100 / total_duration)
+    info["during_percent"] = max(1,
+                                 int(info["duration"] * 100 / total_duration))
+    info[
+        "after_percent"] = 100 - info["before_percent"] - info["during_percent"]
     return info
 
 
@@ -145,13 +148,13 @@ def render_report(output_file, workflow_id):
         "time_now_str": time.strftime("%Y-%m-%d %H:%M:%S", time.localtime()),
     }
     # derived context
-    context["master_id"] = next(iter(context["workflows"].values()))["master_id"]
+    context["master_id"] = next(iter(
+        context["workflows"].values()))["master_id"]
     try:
         # calculate percentage
         start_time = context["workflows"][context["master_id"]]["start_time"]
         total_duration = (
-            context["workflows"][context["master_id"]]["end_time"] - start_time
-        )
+            context["workflows"][context["master_id"]]["end_time"] - start_time)
         for info in context["workflows"].values():
             calc_timeline(info, start_time, total_duration)
         for steps in context["steps"].values():
