@@ -1,10 +1,16 @@
-import pytest
 import os
+import pathlib
 import shutil
+import string
+import subprocess
 import tempfile
 import textwrap
-import pathlib
+import glob
+import random
+
+import pytest
 import yaml
+from sos.utils import env
 
 
 @pytest.fixture
@@ -67,6 +73,17 @@ def temp_factory():
                     shutil.rmtree(dir)
                 os.makedirs(dir, exist_ok=True)
                 temp_dirs.append(dir)
+        if 'size' in kwargs:
+            fsize = kwargs['size']
+            letters = string.ascii_letters
+            content = ''.join(random.choice(letters) for i in range(983)).encode()
+            ntimes = fsize // 983
+            remaining = fsize - (ntimes * 983)
+            for name in temp_fds:
+                with open(name, 'wb') as tmp:
+                    for i in range(ntimes):
+                        tmp.write(content)
+                    tmp.write(content[:remaining])
         return temp_fds, temp_dirs
 
     yield get_tempfiles
@@ -99,6 +116,9 @@ def clear_now_and_after():
                     os.remove(temp_fd)
                 elif os.path.isdir(temp_fd):
                     shutil.rmtree(temp_fd)
+                else:
+                    for tmpfile in glob.glob(temp_fd + '.??????.bak'):
+                        os.remove(tmpfile)
             except Exception:
                 pass
 
@@ -116,6 +136,20 @@ def clear_now_and_after():
 
     clear_files_and_dirs()
 
+
+@pytest.fixture
+def purge_tasks():
+    subprocess.call(["sos", "purge", "--all"])
+
+@pytest.fixture
+def clear_signatures():
+    subprocess.call(["sos", "remove", "-s"])
+
+@pytest.fixture
+def reset_env():
+    env.reset()
+
+
 @pytest.fixture
 def sample_workflow():
     with open('sample_workflow.ipynb', 'w') as sn:
@@ -258,6 +292,9 @@ def sample_workflow():
 }
 ''')
 
+    yield 'sample_workflow.ipynb'
+
+    os.remove('sample_workflow.ipynb')
 
 @pytest.fixture
 def fastq_files():
@@ -469,3 +506,58 @@ AGGGTGGGGAGAATTACAAAGAACCTTCTTAAGAGTGGGGGAGATTACAAAGAACATTCTTAAGGGTGAGGGAGATTACA
 +
 <A<FAF7A(<AFFKKA<KKKAFKF7<FKFKKKKK7,7,,(AFAKFKKFKAKKAKAFK7A,,FFA,<F7,,AAFFFK<FFAKKAFKF<,AAAFAFAK7FKK
 ''')
+
+    yield
+
+    shutil.rmtree('data')
+
+
+@pytest.fixture
+def test_workflow(clear_now_and_after):
+    clear_now_and_after('temp')
+    os.mkdir('temp')
+    os.chdir('temp')
+    with open('test.sos', 'w') as script:
+        script.write('''
+[0]
+output:  't_f1'
+run:
+    touch t_f1
+
+[1]
+output:  't_d1/t_f2'
+run:
+    touch t_d1/t_f2
+    touch t_d1/ut_f4
+
+[2]
+output:  't_d2/t_d3/t_f3'
+run:
+    touch t_d2/t_d3/t_f3
+
+''')
+    subprocess.call('sos run test -s force', shell=True)
+    # create some other files and directory
+    for d in ('ut_d1', 'ut_d2', 'ut_d2/ut_d3'):
+        os.mkdir(d)
+    for f in ('ut_f1', 'ut_d1/ut_f2', 'ut_d2/ut_d3/ut_f3'):
+        with open(f, 'w') as tf:
+            tf.write(f)
+
+#
+# We do not apply this automatically for now.
+#
+#@pytest.fixture(autouse=True)
+def check_extra_files(request, output_file='extra_files.txt'):
+    file_list = os.listdir('.') + [output_file]
+
+    yield
+
+    with open(output_file, 'a') as ofile:
+        for item in os.listdir('.'):
+            if item not in file_list:
+                ofile.write(f'{request.node.name}:\t{item}\n')
+                if os.path.isfile(item):
+                    os.remove(item)
+                elif os.path.isdir(item):
+                    shutil.rmtree(item)
