@@ -9,9 +9,8 @@ import shutil
 import socket
 import sys
 import time
-import platform
-import pytest
 
+import pytest
 from sos import execute_workflow
 from sos.parser import SoS_Script
 from sos.targets import file_target
@@ -35,74 +34,59 @@ with_network = internet_on()
 def test_acceptable_args():
     """test acceptable args of options"""
     with pytest.raises(Exception):
-        execute_workflow(
-            r"""
+        execute_workflow(r"""
             run: unrecog=1
             echo 'a'
-            """
-        )
+            """)
 
 
 def test_get_output():
     """Test utility function get_output"""
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [0: shared='ret']
         ret = get_output('echo blah')
-        """
-    )
+        """)
     # use strip because there would be \r\n under windows
     assert env.sos_dict["ret"].strip() == "blah"
 
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [0: shared='ret']
         ret = get_output('echo blah', show_command=True)
-        """
-    )
+        """)
     assert [x.strip() for x in env.sos_dict["ret"].splitlines()] == [
         "$ echo blah",
         "blah",
     ]
 
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [0: shared='ret']
         ret = get_output('echo blah', show_command=True, prompt='% ')
-        """
-    )
+        """)
     assert [x.strip() for x in env.sos_dict["ret"].splitlines()] == [
         "% echo blah",
         "blah",
     ]
 
     with pytest.raises(Exception):
-        execute_workflow(
-            r"""
+        execute_workflow(r"""
             [0]
             get_output('catmouse')
-        """
-        )
+        """)
 
     with pytest.raises(Exception):
-        execute_workflow(
-            r"""
+        execute_workflow(r"""
             [0]
             ret = get_output('cat -h')
-            """
-        )
+            """)
 
 
 @pytest.mark.skipif(
-    not shutil.which("bash") or sys.platform == "win32", reason="Needs bash."
-)
+    not shutil.which("bash") or sys.platform == "win32", reason="Needs bash.")
 def test_get_output_extra_kwargs():
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [0]
         ret = get_output('echo "ECHO" | wc -l', executable="/bin/bash")
-        """
-    )
+        """)
 
 
 def test_fail_if(temp_factory):
@@ -111,22 +95,18 @@ def test_fail_if(temp_factory):
 
     # should fail in dryrun mode
     with pytest.raises(Exception):
-        execute_workflow(
-            r"""
+        execute_workflow(r"""
             [0]
             input: 'a.txt'
             fail_if(len(input) == 1)
-            """
-        )
+            """)
 
     with pytest.raises(Exception):
-        execute_workflow(
-            r"""
+        execute_workflow(r"""
             [0]
             input: 'a.txt', 'b.txt'
             fail_if(len(input) == 2)
-        """
-        )
+        """)
 
 
 def test_delayed_fail_if():
@@ -148,9 +128,8 @@ def test_delayed_fail_if():
             config={"worker_procs": ["3"]},
         )
 
-    assert (
-        time.time() - st >= 8
-    ), "Test test should fail only after step 10 is completed"
+    assert (time.time() - st >=
+            8), "Test test should fail only after step 10 is completed"
 
 
 def test_delayed_fail_if_from_nested_workflow():
@@ -176,9 +155,8 @@ def test_delayed_fail_if_from_nested_workflow():
             config={"worker_procs": ["3"]},
         )
 
-    assert (
-        time.time() - st >= 8
-    ), "Test test should fail only after step 10 is completed"
+    assert (time.time() - st >=
+            8), "Test test should fail only after step 10 is completed"
 
 
 def test_warn_if(temp_factory):
@@ -204,8 +182,7 @@ def test_warn_if(temp_factory):
 
 def test_stop_if():
     """Test action stop_if"""
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [0: shared='result']
         rep = range(20)
         result = []
@@ -213,8 +190,7 @@ def test_stop_if():
 
         stop_if(_rep > 10)
         result.append(_rep)
-        """
-    )
+        """)
     assert env.sos_dict["result"] == [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10]
 
 
@@ -223,8 +199,7 @@ def test_stop_if_1(clear_now_and_after):
     # generated output file will be removed
     clear_now_and_after("test_stop_if_0.txt", "test_stop_if_1.txt")
 
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [10]
         rep = range(2)
         input: for_each='rep'
@@ -236,8 +211,7 @@ def test_stop_if_1(clear_now_and_after):
         [20]
         assert(step_input.contains('test_stop_if_0.txt'))
         assert(not step_input.contains('test_stop_if_1.txt'))
-        """
-    )
+        """)
 
     assert os.path.isfile("test_stop_if_0.txt")
     assert not (os.path.isfile("test_stop_if_1.txt"))
@@ -248,8 +222,7 @@ def test_stop_if_2(clear_now_and_after):
     # generated output file will not be removed
     clear_now_and_after("test_stop_if_0.txt", "test_stop_if_1.txt")
 
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [10]
         rep = range(2)
         input: for_each='rep'
@@ -261,16 +234,14 @@ def test_stop_if_2(clear_now_and_after):
         [20]
         assert(step_input.contains('test_stop_if_0.txt'))
         assert(step_input.contains('test_stop_if_1.txt'))
-        """
-    )
+        """)
     assert os.path.isfile("test_stop_if_0.txt")
     assert os.path.isfile("test_stop_if_1.txt")
 
 
 def test_skip_if():
     """Test action stop_if"""
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [0: shared='result']
         rep = range(20)
         result = []
@@ -278,8 +249,7 @@ def test_skip_if():
 
         skip_if(_rep > 10)
         result.append(_rep)
-        """
-    )
+        """)
     assert env.sos_dict["result"] == [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10]
 
 
@@ -289,8 +259,7 @@ def test_skip_if_1(clear_now_and_after):
     # stop_if should not be treated as error so the previously
     # generated output file will be removed
 
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [10]
         rep = range(2)
         input: for_each='rep'
@@ -303,8 +272,7 @@ def test_skip_if_1(clear_now_and_after):
         assert(step_input.contains('test_stop_if_0.txt'))
         assert(not step_input.contains('test_stop_if_1.txt'))
 
-        """
-    )
+        """)
 
     assert os.path.isfile("test_stop_if_0.txt")
     assert not os.path.isfile("test_stop_if_1.txt")
@@ -314,8 +282,7 @@ def test_done_if(clear_now_and_after):
     "Test action done_if"
     clear_now_and_after([f"test_done_if_{rep}.txt" for rep in range(2)])
 
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [10]
         rep = range(2)
         input: for_each='rep'
@@ -328,69 +295,58 @@ def test_done_if(clear_now_and_after):
         assert(step_input.contains('test_done_if_0.txt'))
         assert(step_input.contains('test_done_if_1.txt'))
 
-        """
-    )
+        """)
     assert os.path.isfile("test_done_if_0.txt")
     assert os.path.isfile("test_done_if_1.txt")
 
 
 def test_run():
     """Test action run"""
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [0]
         run:
         echo 'Echo'
-        """
-    )
+        """)
 
 
 @pytest.mark.skipif(
-    sys.platform == "win32", reason="Under windows, echo 'Echo is perfectly OK"
-)
+    sys.platform == "win32", reason="Under windows, echo 'Echo is perfectly OK")
 def test_run_1():
 
     with pytest.raises(Exception):
-        execute_workflow(
-            r"""
+        execute_workflow(r"""
             [0]
             run:
             echo 'Echo
-            """
-        )
+            """)
 
 
 def test_run_with_shebang():
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [0]
         run:
         #!/usr/bin/env python
         print('Echo')
-        """
-    )
+        """)
 
 
 @pytest.mark.skipif(not shutil.which("perl"), reason="Needs perl")
 def test_perl():
     """Test action perl"""
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [0]
         perl:
         use strict;
         use warnings;
 
         print "hi NAME\n";
-        """
-    )
+        """)
 
 
 @pytest.mark.skipif(not shutil.which("ruby"), reason="Needs ruby")
 def test_ruby():
     """Test action ruby"""
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [0]
         ruby:
         line1 = "Cats are smarter than dogs";
@@ -402,8 +358,7 @@ def test_ruby():
         if ( line2 =~ /Cats(.*)/ )
         puts "Line2 contains  Dogs"
         end
-        """
-    )
+        """)
 
 
 @pytest.mark.skipif(
@@ -417,36 +372,30 @@ def test_download(temp_factory, clear_now_and_after):
     temp_factory(dir="tmp")
 
     # test decompress tar.gz file
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [0]
         download(['http://bioinformatics.mdanderson.org/Software/VariantTools/repository/annoDB/CancerGeneCensus-20170912.DB.gz'],
         dest_dir='tmp', decompress=True)
-        """
-    )
+        """)
     assert os.path.isfile("tmp/CancerGeneCensus-20170912.DB")
 
     #
     # testing the download of single file
     #
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [0]
         download: dest_file='tmp/refgene.ppp'
         http://bioinformatics.mdanderson.org/Software/VariantTools/repository/resource/refgene.pkl
-        """
-    )
+        """)
 
     assert os.path.isfile("tmp/refgene.ppp")
 
     # test option dest_dir
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [0]
         download: dest_dir='tmp'
         http://bioinformatics.mdanderson.org/Software/VariantTools/repository/resource/refgene.pkl
-        """
-    )
+        """)
     assert os.path.isfile("tmp/refgene.pkl")
 
 
@@ -460,16 +409,14 @@ def test_download_missing_file(temp_factory, clear_now_and_after):
     temp_factory(dir="tmp")
 
     with pytest.raises(Exception):
-        execute_workflow(
-            r"""
+        execute_workflow(r"""
             [0]
             download: dest_dir='tmp', decompress=True, max_jobs=2
             http://bioinformatics.mdanderson.org/Software/VariantTools/repository/resource/non-existing.gz
             http://bioinformatics.mdanderson.org/Software/VariantTools/repository/annoDB/CancerGeneCensus-20170912.DB.gz
             http://bioinformatics.mdanderson.org/Software/VariantTools/repository/annoDB/CancerGeneCensus.ann
             http://bioinformatics.mdanderson.org/Software/VariantTools/repository/annoDB/DGV-hg38_20160831.ann
-            """
-        )
+            """)
 
     assert os.path.isfile("tmp/CancerGeneCensus.ann")
 
@@ -484,26 +431,22 @@ def test_download_large_file(temp_factory, clear_now_and_after):
     clear_now_and_after("tmp")
     temp_factory(dir="tmp")
 
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [0]
         download: dest_dir='tmp', decompress=True
         http://bioinformatics.mdanderson.org/Software/VariantTools/repository/annoDB/CancerGeneCensus-20170912.DB.gz
         http://bioinformatics.mdanderson.org/Software/VariantTools/repository/annoDB/CancerGeneCensus.ann
         http://bioinformatics.mdanderson.org/Software/VariantTools/repository/annoDB/DGV-hg38_20160831.ann
-        """
-    )
+        """)
 
     # run in build mode
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [0]
         download: dest_dir='tmp', decompress=True
         http://bioinformatics.mdanderson.org/Software/VariantTools/repository/annoDB/CancerGeneCensus-20170912.DB.gz
         http://bioinformatics.mdanderson.org/Software/VariantTools/repository/annoDB/CancerGeneCensus.ann
         http://bioinformatics.mdanderson.org/Software/VariantTools/repository/annoDB/DGV-hg38_20160831.ann
-        """
-    )
+        """)
 
 
 @pytest.mark.skipif(not shutil.which("pandoc"), reason="Needs pandoc")
@@ -511,8 +454,7 @@ def test_pandoc(clear_now_and_after):
     """Test action pandoc"""
     clear_now_and_after("report.md", "myreport.html")
 
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [10]
 
         report: output='report.md'
@@ -525,8 +467,7 @@ def test_pandoc(clear_now_and_after):
         # generate report
         output: 'myreport.html'
         pandoc(input='report.md', output=_output[0])
-        """
-    )
+        """)
 
     assert os.path.isfile("myreport.html")
 
@@ -535,8 +476,7 @@ def test_pandoc(clear_now_and_after):
 def test_pandoc_1(clear_now_and_after):
     clear_now_and_after("a.md", "myreport.html")
 
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [10]
         report: output='a.md'
         ## Some random figure
@@ -548,8 +488,7 @@ def test_pandoc_1(clear_now_and_after):
         # generate report
         output: 'myreport.html'
         pandoc(input='a.md', output=_output[0])
-        """
-    )
+        """)
 
     assert os.path.isfile("myreport.html")
 
@@ -559,8 +498,7 @@ def test_pandoc_2(clear_now_and_after):
     clear_now_and_after("a.md", "myreport.html")
     #
     # another case is no output
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [10]
         report: output='a.md'
         ## Some random figure
@@ -571,8 +509,7 @@ def test_pandoc_2(clear_now_and_after):
         [100]
         # generate report
         pandoc(input='a.md')
-        """
-    )
+        """)
 
 
 @pytest.mark.skipif(not shutil.which("pandoc"), reason="Needs pandoc")
@@ -580,8 +517,7 @@ def test_pandoc_3(clear_now_and_after):
     # test acceptance of a list of input filenames
     clear_now_and_after("default_10.md", "default_20.md", "output.html")
 
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [10]
         report: output='default_10.md'
         A_10
@@ -593,8 +529,7 @@ def test_pandoc_3(clear_now_and_after):
         [100]
         # generate report
         pandoc(input=['default_10.md', 'default_20.md'], output='output.html')
-        """
-    )
+        """)
 
     for f in ["default_10.md", "default_20.md", "output.html"]:
         assert file_target(f).target_exists()
@@ -623,8 +558,7 @@ def test_report_1(clear_now_and_after):
     """Test action report"""
     clear_now_and_after("report.txt")
 
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [A]
         report: output='report.txt', expand=True
         {step_name}
@@ -632,8 +566,7 @@ def test_report_1(clear_now_and_after):
         [A_10]
         report: output='report.txt', expand=True
         {step_name}
-        """
-    )
+        """)
     with open("report.txt") as report:
         assert report.read() == "A_10\n\n"
 
@@ -642,15 +575,13 @@ def test_report_2(clear_now_and_after):
     """Test action report"""
     clear_now_and_after("a.txt", "out.txt")
 
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [A_1]
         run: output='a.txt'
             echo something > a.txt
 
         report(input='a.txt', output='out.txt')
-        """
-    )
+        """)
 
     for name in ("a.txt", "out.txt"):
         with open(name) as report:
@@ -659,10 +590,9 @@ def test_report_2(clear_now_and_after):
 
 def test_report_3(clear_now_and_after):
     """Test action report"""
-    clear_now_and_after("report.txt")
+    clear_now_and_after("report.txt", "out.txt", "a.txt", "b.txt")
     #
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [A_1]
         run: output='a.txt'
         echo something > a.txt
@@ -673,8 +603,7 @@ def test_report_3(clear_now_and_after):
 
         [A_3]
         report(input=['a.txt', 'b.txt'], output='out.txt')
-        """
-    )
+        """)
     for name in ("a.txt", "b.txt", "out.txt"):
         assert file_target(name).target_exists()
 
@@ -684,27 +613,23 @@ def test_report_4(clear_now_and_after):
     clear_now_and_after("a.txt")
 
     # test report to other types of output: path
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [A_1]
         report: output=path('a.txt')
         something
-        """
-    )
+        """)
 
 
 def test_report_5(clear_now_and_after):
     """Test action report"""
     clear_now_and_after("a.txt")
 
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [A_1]
         output: 'a.txt'
         report: output=_output[0]
         something
-        """
-    )
+        """)
 
 
 def test_report_6(clear_now_and_after):
@@ -712,14 +637,12 @@ def test_report_6(clear_now_and_after):
     clear_now_and_after("a.txt")
 
     # test report to other types of output: sos_targets
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [A_1]
         output: 'a.txt'
         report: output=_output
         something
-        """
-    )
+        """)
 
 
 def test_report_7(clear_now_and_after):
@@ -727,14 +650,12 @@ def test_report_7(clear_now_and_after):
     clear_now_and_after("a.txt")
 
     with pytest.raises(Exception):
-        execute_workflow(
-            r"""
+        execute_workflow(r"""
             [A_1]
             output: 'a.txt', 'b.txt'
             report: output=_output
             something
-            """
-        )
+            """)
 
 
 def test_option_workdir(temp_factory):
@@ -744,29 +665,26 @@ def test_option_workdir(temp_factory):
     with open(os.path.join("temp_wdr", "a.txt"), "w") as tmp:
         tmp.write("hello")
 
-    execute_workflow(
-        r"""
+    execute_workflow(r"""
         [A_1]
         run: workdir='temp_wdr'
         cp -f a.txt a2.txt
-        """
-    )
+        """)
 
     assert file_target(os.path.join("temp_wdr", "a2.txt")).target_exists()
     with open(os.path.join("temp_wdr", "a.txt")) as tmp:
         assert "hello" == tmp.read()
 
 
-def test_action_script():
+def test_action_script(clear_now_and_after):
     """Test action script"""
-    execute_workflow(
-        r"""
+    clear_now_and_after("something.txt")
+    execute_workflow(r"""
         [A_1]
         script: interpreter='python'
         with open('something.txt', 'w') as tmp:
             tmp.write('something')
-        """
-    )
+        """)
 
     assert file_target("something.txt").target_exists()
     with open("something.txt") as tmp:
@@ -776,7 +694,7 @@ def test_action_script():
 def test_regenerate_report(clear_now_and_after):
     """Testing the regeneration of report once is needed. The problem
     here is the 'input' parameter of report."""
-    clear_now_and_after("a1.md", "a2.md", "out.md")
+    clear_now_and_after("a1.md", "a2.md", "out.md", "a1.txt", "a2.txt")
     script = r"""
         [A_1]
         output: 'a1.txt', 'a1.md'
@@ -814,8 +732,7 @@ def test_active_action_option(temp_factory):
     """Test the active option of actions"""
     # disallow
     with pytest.raises(Exception):
-        SoS_Script(
-            """
+        SoS_Script("""
 [1]
 rep = range(5)
 input: for_each = 'rep'
@@ -824,8 +741,7 @@ ff = f"{_rep}.txt"
 run:  expand=True, active=1,2
 echo {ff}
 touch temp/{ff}
-"""
-        )
+""")
     #
     for active, result in [
         ("0", ["temp/0.txt"]),
@@ -833,20 +749,23 @@ touch temp/{ff}
         ("(1,2)", ["temp/1.txt", "temp/2.txt"]),
         ("[2,3]", ["temp/2.txt", "temp/3.txt"]),
         ("(0,2,4)", ["temp/0.txt", "temp/2.txt", "temp/4.txt"]),
-        ("slice(1,None)", ["temp/1.txt", "temp/2.txt", "temp/3.txt", "temp/4.txt"]),
+        ("slice(1,None)",
+         ["temp/1.txt", "temp/2.txt", "temp/3.txt", "temp/4.txt"]),
         ("slice(1,-2)", ["temp/1.txt", "temp/2.txt"]),
         ("slice(None,None,2)", ["temp/0.txt", "temp/2.txt", "temp/4.txt"]),
         (
             "True",
-            ["temp/0.txt", "temp/1.txt", "temp/2.txt", "temp/3.txt", "temp/4.txt"],
+            [
+                "temp/0.txt", "temp/1.txt", "temp/2.txt", "temp/3.txt",
+                "temp/4.txt"
+            ],
         ),
         ("False", []),
     ]:
         temp_factory(dir="temp")
         # test first iteration
         execute_workflow(
-            (
-                """
+            ("""
             [1]
             rep = range(5)
             input: for_each = 'rep'
@@ -855,9 +774,7 @@ touch temp/{ff}
             run:  expand=True, active=%s
             echo {ff}
             touch temp/{ff}
-            """
-                % active
-            ).replace("/", os.sep),
+            """ % active).replace("/", os.sep),
             options={"sig_mode": "force"},
         )
 
@@ -868,24 +785,20 @@ touch temp/{ff}
 def test_action_option_template(clear_now_and_after):
     clear_now_and_after("template_output.txt")
 
-    execute_workflow(
-        """
+    execute_workflow("""
         run:  template='cat {filename}'
             echo 'whatever' > template_output.txt
-        """
-    )
+        """)
     assert not os.path.isfile("template_output.txt")
 
 
 def test_action_option_template_name(config_factory):
-    cfg = config_factory(
-        """\
+    cfg = config_factory("""\
         action_templates:
             cat: |
                 cat {filename}
 
-        """
-    )
+        """)
     execute_workflow(
         """
         run:  template_name='cat'
