@@ -7,7 +7,6 @@ import textwrap
 from io import StringIO
 
 import pytest
-
 from sos import execute_workflow
 from sos.parser import SoS_Script
 from sos.targets import file_target
@@ -62,8 +61,8 @@ def test_simple_dag(temp_factory):
 
             [A_3]
 
-            [A_4]''')
-        , textwrap.dedent('''strict digraph "" {
+            [A_4]'''),
+        textwrap.dedent('''strict digraph "" {
             A_2;
             A_4;
             A_1;
@@ -84,8 +83,8 @@ def test_simple_dag(temp_factory):
             [A_3]
             input: 'a.txt'
 
-            [A_4]''')
-        , textwrap.dedent('''strict digraph "" {
+            [A_4]'''),
+        textwrap.dedent('''strict digraph "" {
             A_2;
             A_4;
             A_1;
@@ -114,8 +113,8 @@ def test_simple_dag(temp_factory):
             [A_4]
             input: 'd.txt'
             output: 'e.txt'
-            ''')
-        , textwrap.dedent('''strict digraph "" {
+            '''),
+        textwrap.dedent('''strict digraph "" {
             A_2;
             A_4;
             A_1;
@@ -146,8 +145,8 @@ def test_simple_dag(temp_factory):
             [B_4]
             input: 'd.txt'
             output: 'e.txt'
-            ''')
-        , textwrap.dedent('''strict digraph "" {
+            '''),
+        textwrap.dedent('''strict digraph "" {
             B_2;
             B_4;
             B_1;
@@ -177,8 +176,8 @@ def test_simple_dag(temp_factory):
             [B_4]
             input: 'd.txt'
             output: 'e.txt'
-            ''')
-        , textwrap.dedent('''strict digraph "" {
+            '''),
+        textwrap.dedent('''strict digraph "" {
             B_1;
             B_4;
             B_2;
@@ -209,8 +208,8 @@ def test_simple_dag(temp_factory):
             [C_4]
             depends: 'd.txt'
             output: 'e.txt'
-            ''')
-        , textwrap.dedent('''
+            '''),
+        textwrap.dedent('''
             strict digraph "" {
             C_1;
             C_4;
@@ -222,6 +221,7 @@ def test_simple_dag(temp_factory):
             }
             '''))
 
+
 def test_undetermined(temp_factory):
     '''Test DAG with undetermined input.'''
     #
@@ -246,9 +246,10 @@ def test_undetermined(temp_factory):
             depends: 'd.txt'
             output: 'e.txt'
             ''')
-                # dag.show_nodes()
-                # dag.save('a.dot')
-        , textwrap.dedent('''
+        # dag.show_nodes()
+        # dag.save('a.dot')
+        ,
+        textwrap.dedent('''
             strict digraph "" {
             C_1;
             C_4;
@@ -278,8 +279,8 @@ def test_undetermined(temp_factory):
             [C_4]
             depends: 'd.txt'
             output: 'e.txt'
-            ''')
-        , textwrap.dedent('''
+            '''),
+        textwrap.dedent('''
             strict digraph "" {
             C_1;
             C_4;
@@ -291,7 +292,8 @@ def test_undetermined(temp_factory):
             }
             '''))
 
-def test_auxiliary_steps(temp_factory,clear_now_and_after):
+
+def test_auxiliary_steps(temp_factory, clear_now_and_after):
     graph = textwrap.dedent(('''
         [K: provides='{name}.txt']
         output: f"{name}.txt"
@@ -324,7 +326,8 @@ def test_auxiliary_steps(temp_factory,clear_now_and_after):
     #
     dag.show_nodes()
     assertDAG(
-        dag, textwrap.dedent('''
+        dag,
+        textwrap.dedent('''
         strict digraph "" {
         "K (b.txt)";
         C_3;
@@ -333,6 +336,7 @@ def test_auxiliary_steps(temp_factory,clear_now_and_after):
         }
         '''))
 
+
 def test_cycle():
     '''Test cycle detection of DAG'''
     #
@@ -342,7 +346,8 @@ def test_cycle():
     #
     #  C.txt --> A.txt
     #
-    script = SoS_Script(textwrap.dedent('''
+    script = SoS_Script(
+        textwrap.dedent('''
     [A_1]
     input: 'A.txt'
     output: 'B.txt'
@@ -355,13 +360,15 @@ def test_cycle():
     '''))
     # the workflow should call step K for step C_2, but not C_3
     wf = script.workflow()
-    pytest.raises(RuntimeError, Base_Executor(wf).initialize_dag)
+    with pytest.raises(RuntimeError):
+        Base_Executor(wf).initialize_dag()
+
 
 def test_long_chain(clear_now_and_after):
     '''Test long make file style dependencies.'''
     #
-    clear_now_and_after('A1.txt', 'A2.txt', 'C2.txt', 'B2.txt', 
-        'B1.txt', 'B3.txt', 'C1.txt', 'C3.txt', 'C4.txt')
+    clear_now_and_after('A1.txt', 'A2.txt', 'C2.txt', 'B2.txt', 'B1.txt',
+                        'B3.txt', 'C1.txt', 'C3.txt', 'C4.txt')
 
     #
     #  A1 <- B1 <- B2 <- B3
@@ -420,8 +427,8 @@ def test_long_chain(clear_now_and_after):
         run:
             touch C4.txt
 
-        ''')
-    , textwrap.dedent('''
+        '''),
+        textwrap.dedent('''
         strict digraph "" {
         "C4 (C4.txt)";
         "B1 (B1.txt)";
@@ -445,11 +452,12 @@ def test_long_chain(clear_now_and_after):
         }
         '''))
 
+
 def test_target(clear_now_and_after):
     '''Test executing only part of a workflow.'''
     #
-    clear_now_and_after('A1.txt', 'A2.txt', 'C2.txt', 'B2.txt', 
-        'B1.txt', 'B3.txt', 'C1.txt', 'C3.txt', 'C4.txt')
+    clear_now_and_after('A1.txt', 'A2.txt', 'C2.txt', 'B2.txt', 'B1.txt',
+                        'B3.txt', 'C1.txt', 'C3.txt', 'C4.txt')
     #
     #  A1 <- B1 <- B2 <- B3
     #   |
@@ -458,7 +466,8 @@ def test_target(clear_now_and_after):
     #  A2 <- B2 <- C1 <- C2 <- C4
     #                    C3
     #
-    script = SoS_Script(textwrap.dedent('''
+    script = SoS_Script(
+        textwrap.dedent('''
     [A1]
     input: 'B1.txt'
     output: 'A1.txt'
@@ -511,7 +520,8 @@ def test_target(clear_now_and_after):
     dag = Base_Executor(wf).initialize_dag(targets=['B1.txt'])
     # note that A2 is no longer mentioned
     assertDAG(
-        dag, textwrap.dedent('''
+        dag,
+        textwrap.dedent('''
         strict digraph "" {
         "B3 (B3.txt)";
         "C4 (C4.txt)";
@@ -534,7 +544,8 @@ def test_target(clear_now_and_after):
     dag = Base_Executor(wf).initialize_dag(targets=['B2.txt', 'C2.txt'])
     # note that A2 is no longer mentioned
     assertDAG(
-        dag, textwrap.dedent('''
+        dag,
+        textwrap.dedent('''
         strict digraph "" {
         "C4 (C4.txt)";
         "B2 (B2.txt)";
@@ -556,7 +567,8 @@ def test_target(clear_now_and_after):
     dag = Base_Executor(wf).initialize_dag(targets=['B3.txt', 'C2.txt'])
     # note that A2 is no longer mentioned
     assertDAG(
-        dag, textwrap.dedent('''
+        dag,
+        textwrap.dedent('''
         strict digraph "" {
         "B3 (B3.txt)";
         "C2 (C2.txt)";
@@ -565,10 +577,12 @@ def test_target(clear_now_and_after):
         }
         '''))
 
+
 def test_pattern_reuse(clear_now_and_after):
     '''Test repeated use of steps that use pattern and produce different files.'''
     #
-    clear_now_and_after('A1.txt', 'A2.txt', 'B1.txt', 'B1.txt.p', 'B2.txt', 'B2.txt.p')
+    clear_now_and_after('A1.txt', 'A2.txt', 'B1.txt', 'B1.txt.p', 'B2.txt',
+                        'B2.txt.p')
     #
     #  A1 <- P <- B1
     #  A1 <- P <- B2
@@ -600,8 +614,8 @@ def test_pattern_reuse(clear_now_and_after):
         input: filename
         run: expand=True
             touch {_output}
-        ''')
-    , textwrap.dedent('''
+        '''),
+        textwrap.dedent('''
         strict digraph "" {
         "P (B2.txt.p)";
         "B1 (B1.txt)";
@@ -617,6 +631,7 @@ def test_pattern_reuse(clear_now_and_after):
         }
         '''))
 
+
 def test_parallel_execution(clear_now_and_after):
     '''Test basic parallel execution
     A1 <- None
@@ -644,8 +659,8 @@ def test_parallel_execution(clear_now_and_after):
         run:
             touch B2.txt
 
-        ''')
-    , textwrap.dedent('''
+        '''),
+        textwrap.dedent('''
         strict digraph "" {
         A_1;
         A_2;
@@ -657,6 +672,7 @@ def test_parallel_execution(clear_now_and_after):
     #env.verbosity = 4
     # the process is slower after switching to spawn mode
 
+
 def test_shared_dependency(clear_now_and_after):
     #
     # shared variable should introduce additional dependency
@@ -665,7 +681,8 @@ def test_shared_dependency(clear_now_and_after):
     #
     # A1 introduces a shared variable ss, A3 depends on ss but not A2
     #
-    script = SoS_Script(textwrap.dedent('''
+    script = SoS_Script(
+        textwrap.dedent('''
     [A_1: shared='ss']
     ss = 'A1'
 
@@ -686,7 +703,8 @@ def test_shared_dependency(clear_now_and_after):
     wf = script.workflow('A')
     dag = Base_Executor(wf).initialize_dag()
     assertDAG(
-        dag, textwrap.dedent('''
+        dag,
+        textwrap.dedent('''
         strict digraph "" {
         A_3;
         A_1;
@@ -696,13 +714,15 @@ def test_shared_dependency(clear_now_and_after):
         '''))
     env.max_jobs = 3
 
+
 def test_literal_connection(clear_now_and_after):
     '''Testing the connection of steps with by variables.'''
     clear_now_and_after('A1.txt')
     #
     # A1 introduces a shared variable ss, A3 depends on ss but not A2
     #
-    script = SoS_Script(textwrap.dedent('''
+    script = SoS_Script(
+        textwrap.dedent('''
     [A_1: shared='p']
     run:
         touch 'A1.txt'
@@ -735,7 +755,8 @@ def test_literal_connection(clear_now_and_after):
     wf = script.workflow('A')
     dag = Base_Executor(wf).initialize_dag()
     assertDAG(
-        dag, textwrap.dedent('''
+        dag,
+        textwrap.dedent('''
         strict digraph "" {
         A_1;
         A_4;
@@ -749,75 +770,71 @@ def test_literal_connection(clear_now_and_after):
         '''))
     env.max_jobs = 3
 
+
 def test_variable_target():
     '''Test dependency caused by variable usage.'''
-    script = SoS_Script(textwrap.dedent(r'''
-    [A: shared='b']
-    b = 1
+    execute_workflow(
+        r'''
+        [A: shared='b']
+        b = 1
 
-    [C: shared={'c':'k'}]
-    k = 2
+        [C: shared={'c':'k'}]
+        k = 2
 
-    [all: shared='p']
-    depends: sos_variable('c'), sos_variable('b')
+        [all: shared='p']
+        depends: sos_variable('c'), sos_variable('b')
 
-    p = c + b
+        p = c + b
 
-    '''))
-    wf = script.workflow('all')
-    Base_Executor(wf).run()
+        ''',
+        workflow='all')
     assert env.sos_dict['p'] == 3
 
+
 def test_reverse_shared_variable(clear_now_and_after):
     '''Test shared variables defined in auxiliary steps'''
     clear_now_and_after('a.txt')
-    script = SoS_Script(textwrap.dedent(r'''
-    [A: shared='b', provides='a.txt']
-    b = 1
-    run:
-    touch a.txt
+    execute_workflow(
+        r'''
+        [A: shared='b', provides='a.txt']
+        b = 1
+        run:
+        touch a.txt
 
-    [B_1]
-    depends: 'a.txt'
+        [B_1]
+        depends: 'a.txt'
 
-    [B_2]
-    print(b)
+        [B_2]
+        print(b)
 
-    '''))
-    wf = script.workflow('B')
-    Base_Executor(wf).run()
+        ''',
+        workflow='B')
     assert env.sos_dict['b'] == 1
 
+
 def test_chained_depends(temp_factory):
     '''Test chain dependent'''
     temp_factory('a.bam', 'a.bam.bai', 'a.vcf')
-    script = SoS_Script(textwrap.dedent(r'''
-    # this step provides variable `var`
-    [index: provides='{filename}.bam.bai']
-    input: f"{filename}.bam"
-    run: expand=True
-    echo "Generating {_output}"
-    touch {_output}
+    execute_workflow(
+        r'''
+        # this step provides variable `var`
+        [index: provides='{filename}.bam.bai']
+        input: f"{filename}.bam"
+        run: expand=True
+        echo "Generating {_output}"
+        touch {_output}
 
-    [call: provides='{filename}.vcf']
-    input:   f"{filename}.bam"
-    depends: f"{_input}.bai"
-    run: expand=True
-    echo "Calling variants from {_input} with {_depends} to {_output}"
-    touch {_output}
-    '''))
-    # if file_target('a.bam.bai').exists():
-    #     file_target('a.bam.bai').unlink()
-    # if file_target('a.vcf').exists():
-    #     file_target('a.vcf').unlink()
-    # self.touch('a.bam')
-    Base_Executor(script.workflow()).run(targets=['a.vcf'])
-    # for f in ('a.vcf', 'a.bam', 'a.bam.bai'):
-    #     if file_target(f).exists():
-    #         file_target(f).unlink()
+        [call: provides='{filename}.vcf']
+        input:   f"{filename}.bam"
+        depends: f"{_input}.bai"
+        run: expand=True
+        echo "Calling variants from {_input} with {_depends} to {_output}"
+        touch {_output}
+        ''',
+        targets=['a.vcf'])
 
-@pytest.mark.skipif(
-    True, reason='This test is failing')
+
+@pytest.mark.skipif(True, reason='This test is failing')
 def test_output_of_dag(clear_now_and_after):
     '''Test output of dag'''
     #
@@ -832,7 +849,8 @@ def test_output_of_dag(clear_now_and_after):
     #  A2 <- B2 <- C1 <- C2 <- C4
     #                    C3
     #
-    script = SoS_Script(textwrap.dedent('''
+    script = SoS_Script(
+        textwrap.dedent('''
     [A_1]
     input: 'B1.txt'
     output: 'A1.txt'
@@ -883,14 +901,14 @@ def test_output_of_dag(clear_now_and_after):
     #
     # test 1, we only need to generate target 'B1.txt'
     Base_Executor(
-        wf,
-        config={
+        wf, config={
             'output_dag': 'test_outofdag1.dot',
             'trace_existing': True
         }).initialize_dag(targets=['B1.txt'])
     # note that A2 is no longer mentioned
     assertDAG(
-        'test_outofdag1.dot', textwrap.dedent('''
+        'test_outofdag1.dot',
+        textwrap.dedent('''
         strict digraph "" {
         "B3 (B3.txt)";
         "C4 (C4.txt)";
@@ -910,14 +928,14 @@ def test_output_of_dag(clear_now_and_after):
         '''))
     # test 2, we would like to generate two files
     Base_Executor(
-        wf,
-        config={
+        wf, config={
             'output_dag': 'test_outofdag2.dot',
             'trace_existing': True
         }).initialize_dag(targets=['B2.txt', 'C2.txt'])
     # note that A2 is no longer mentioned
     assertDAG(
-        'test_outofdag2.dot', textwrap.dedent('''
+        'test_outofdag2.dot',
+        textwrap.dedent('''
         strict digraph "" {
         "C4 (C4.txt)";
         "B2 (B2.txt)";
@@ -936,14 +954,14 @@ def test_output_of_dag(clear_now_and_after):
     # test 3, generate two separate trees
     #
     Base_Executor(
-        wf,
-        config={
+        wf, config={
             'output_dag': 'test_outofdag3.dot',
             'trace_existing': True
         }).initialize_dag(targets=['B3.txt', 'C2.txt'])
     # note that A2 is no longer mentioned
     assertDAG(
-        'test_outofdag3.dot', textwrap.dedent('''
+        'test_outofdag3.dot',
+        textwrap.dedent('''
         strict digraph "" {
         "B3 (B3.txt)";
         "C2 (C2.txt)";
@@ -953,11 +971,12 @@ def test_output_of_dag(clear_now_and_after):
         '''))
     clear_now_and_after('C2.txt', 'B3.txt', 'C4.txt', 'test.dot', 'test_2.dot')
 
-@pytest.mark.skipif(
-    True, reason='This test is failing')
+
+@pytest.mark.skipif(True, reason='This test is failing')
 def test_step_with_multiple_output(clear_now_and_after):
     '''Test addition of steps with multiple outputs. It should be added only once'''
-    script = SoS_Script(textwrap.dedent('''
+    script = SoS_Script(
+        textwrap.dedent('''
     [test_1: provides=['{}.txt'.format(i) for i in range(10)]]
     output: ['{}.txt'.format(i) for i in range(10)]
     run:
@@ -979,8 +998,10 @@ def test_step_with_multiple_output(clear_now_and_after):
     assert lc == 6
     clear_now_and_after('test.dot')
 
-def test_auxiliary_sos_step():
+
+def test_auxiliary_sos_step(clear_now_and_after):
     '''Testing the use of sos_step with auxiliary step. #736'''
+    clear_now_and_after('1.txt')
     execute_workflow('''
         [default]
         depends: '1.txt'
@@ -995,7 +1016,8 @@ def test_auxiliary_sos_step():
         touch 1.txt
         ''')
 
-def test_forward_style_depend(clear_now_and_after,temp_factory):
+
+def test_forward_style_depend(clear_now_and_after, temp_factory):
     '''Test the execution of forward-style workflow with undtermined dependency'''
     clear_now_and_after('a.txt.bak')
     temp_factory('a.txt')
@@ -1013,9 +1035,11 @@ def test_forward_style_depend(clear_now_and_after,temp_factory):
         ''')
     assert file_target('a.txt.bak').target_exists()
 
+
 def test_sos_step_miniworkflow(clear_now_and_after):
     '''Test the addition of mini forward workflows introduced by sos_step'''
-    script = SoS_Script(textwrap.dedent('''
+    script = SoS_Script(
+        textwrap.dedent('''
     [a_1]
     print(step_name)
 
@@ -1050,7 +1074,8 @@ def test_sos_step_miniworkflow(clear_now_and_after):
     Base_Executor(wf, config={'output_dag': 'test.dot'}).run()
     # note that A2 is no longer mentioned
     assertDAG(
-        'test.dot', textwrap.dedent('''
+        'test.dot',
+        textwrap.dedent('''
         strict digraph "" {
         default;
         a_1;
@@ -1075,9 +1100,12 @@ def test_sos_step_miniworkflow(clear_now_and_after):
         '''))
     clear_now_and_after('test.dot')
 
+
 def test_compound_workflow(clear_now_and_after):
     '''Test the DAG of compound workflow'''
-    script = SoS_Script(textwrap.dedent('''
+    clear_now_and_after('test.dot')
+    script = SoS_Script(
+        textwrap.dedent('''
     [A_1]
     [A_2]
     [B]
@@ -1085,7 +1113,8 @@ def test_compound_workflow(clear_now_and_after):
     wf = script.workflow('A+B')
     dag = Base_Executor(wf).initialize_dag()
     assertDAG(
-        dag, textwrap.dedent('''strict digraph "" {
+        dag,
+        textwrap.dedent('''strict digraph "" {
         A_1;
         A_2;
         B;
@@ -1093,7 +1122,8 @@ def test_compound_workflow(clear_now_and_after):
         A_2 -> B;
         }'''))
     # with empty depends
-    script = SoS_Script(textwrap.dedent('''
+    script = SoS_Script(
+        textwrap.dedent('''
     [A_1]
     [A_2]
     [B]
@@ -1102,7 +1132,8 @@ def test_compound_workflow(clear_now_and_after):
     wf = script.workflow('A+B')
     dag = Base_Executor(wf).initialize_dag()
     assertDAG(
-        dag, textwrap.dedent('''strict digraph "" {
+        dag,
+        textwrap.dedent('''strict digraph "" {
         A_1;
         A_2;
         B;
@@ -1110,7 +1141,8 @@ def test_compound_workflow(clear_now_and_after):
         A_2 -> B;
         }'''))
     clear_now_and_after('a.txt')
-    script = SoS_Script(textwrap.dedent('''
+    script = SoS_Script(
+        textwrap.dedent('''
     [A_1]
     [A_2]
     [C]
@@ -1124,7 +1156,8 @@ def test_compound_workflow(clear_now_and_after):
     wf = script.workflow('A+B')
     dag = Base_Executor(wf).initialize_dag()
     assertDAG(
-        dag, textwrap.dedent('''strict digraph "" {
+        dag,
+        textwrap.dedent('''strict digraph "" {
         A_1;
         A_2;
         B;
@@ -1134,10 +1167,10 @@ def test_compound_workflow(clear_now_and_after):
         "C (a.txt)" -> B;
         }'''))
 
+
 def test_provides_sos_variable():
     '''Test provides non-filename targets #1341'''
-    execute_workflow(
-        '''
+    execute_workflow('''
         [count: provides=sos_variable('numNotebooks')]
         numNotebooks = 1
 
