@@ -6,23 +6,23 @@
 import os
 import shutil
 import subprocess
+
 import pytest
 from sos import execute_workflow
 
 
+@pytest.mark.xfail(reason="Sometimes there is no permission to install to R")
 @pytest.mark.skipif(
-    not shutil.which("Rscript") or "TRAVIS" in os.environ, reason="R not installed"
-)
+    not shutil.which("Rscript") or "TRAVIS" in os.environ,
+    reason="R not installed")
 def test_r_library():
     """Test target R_Library"""
-    execute_workflow(
-        """
+    execute_workflow("""
         [default]
         depends: R_library("dplyr", autoinstall=True)
         R:
             library('dplyr')
-        """
-    )
+        """)
 
 
 @pytest.mark.skipif(not shutil.which("Rscript"), reason="R not installed")
@@ -30,8 +30,7 @@ def test_depends_r_library():
     """Testing depending on R_library"""
     # first remove xtable package
     subprocess.call("R CMD REMOVE xtable", shell=True)
-    execute_workflow(
-        """
+    execute_workflow("""
         [0]
 
         depends: R_library('xtable', autoinstall=True)
@@ -39,13 +38,13 @@ def test_depends_r_library():
         library('xtable')
         ## Demonstrate data.frame
         tli.table <- xtable(cars)
-        """
-    )
+        """)
 
 
 @pytest.mark.skipif(not shutil.which("Rscript"), reason="R not installed")
-def test_reexecution():
+def test_reexecution(clear_now_and_after):
     """Test re-execution of steps with R_library"""
+    clear_now_and_after('1.txt')
     subprocess.call("R CMD REMOVE xtable", shell=True)
     wf = """
     [1]
